/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import { ChangeDetectorRef, Component, ElementRef, EventEmitter, HostBinding, Input, NgZone, Output, Renderer2, ViewChild, isDevMode } from '@angular/core';
import { validatePackage } from '@progress/kendo-licensing';
import { packageMetadata } from './package-metadata';
import { INITIAL_ZOOM_LEVEL, zoomOptionsData, zoomToFitOptions } from './util';
import { PdfViewer, removeChildren, } from '@progress/kendo-pdfviewer-common';
import { EventsOutsideAngularDirective, hasObservers, shouldShowValidationUI, WatermarkOverlayComponent } from '@progress/kendo-angular-common';
import { LocalizationService, L10N_PREFIX } from '@progress/kendo-angular-l10n';
import { PDFViewerDownloadEvent } from './models/events';
import { saveAs } from '@progress/kendo-file-saver';
import { Subscription } from 'rxjs';
import { ToolbarComponent } from './toolbar/toolbar.component';
import { PDFViewerSearchComponent } from './toolbar/search.component';
import { LoaderComponent } from './loader/loader.component';
import { NgIf } from '@angular/common';
import { LocalizedPDFViewerMessagesDirective } from './localization/localized-messages.directive';
import 'pdfjs-dist/build/pdf.worker.min.mjs';
import * as i0 from "@angular/core";
import * as i1 from "@progress/kendo-angular-l10n";
let counter = 0;
/**
 * Represents the [Kendo UI PDFViewer component for Angular](slug:overview_pdfviewer).
 *
 * @example
 * ```html
 * <kendo-pdfviewer
 *   [url]="pdfUrl"
 *   [zoom]="1.25"
 *   [tools]="['pager', 'zoomInOut', 'zoom', 'download', 'print']">
 * </kendo-pdfviewer>
 * ```
 *
 * @remarks
 * Supported children components are: {@link PDFViewerCustomMessagesComponent}
 */
export class PDFViewerComponent {
    ngZone;
    renderer;
    localizationService;
    cdr;
    host;
    hostClass = true;
    direction;
    /**
     * Represents the tools collection rendered in the toolbar.
     * @default ['pager', 'spacer', 'zoomInOut', 'zoom', 'selection', 'spacer', 'search', 'open', 'download', 'print' ]
     */
    tools = [
        'pager',
        'spacer',
        'zoomInOut',
        'zoom',
        'selection',
        'spacer',
        'search',
        'open',
        'download',
        'print'
    ];
    /**
     * The configuration of the internal Loader component.
     * @default { size: 'large', type: 'pulsing', themeColor: 'primary' }
     */
    loaderSettings = {
        size: 'large',
        type: 'pulsing',
        themeColor: 'primary'
    };
    /**
     * The name of the file that will be saved when the end user clicks the Download tool.
     * @default 'Download'
     */
    saveFileName = 'Download';
    /**
     * Represents the options for saving the file when the end user clicks the Download tool.
     * @default {}
     */
    saveOptions = {};
    /**
     * Represents the url of the PDF file.
     */
    url;
    /**
     * Represents the data of the PDF file in [Base64 format](https://developer.mozilla.org/en-US/docs/Glossary/Base64).
     */
    data;
    /**
     * Represents the raw [binary data buffer](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/ArrayBuffer) of the PDF file.
     */
    arrayBuffer;
    /**
     * Represents the data of the PDF file in [`TypedArray`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/TypedArray) format.
     */
    typedArray;
    /**
     * Sets the initial zoom level of the PDF document
     * ([see example](slug:tools_pdfviewer#zooming-tools)).
     *
     * @default 1.25
     */
    set zoom(value) {
        if (typeof value === 'number') {
            this._zoom = value;
            this._fitType = null;
            this.setZoomLevel(value);
        }
        else {
            this._zoom = INITIAL_ZOOM_LEVEL;
            this._fitType = zoomToFitOptions[value];
        }
        this._zoomToFit = typeof value !== 'number';
    }
    get zoom() {
        return this._zoom;
    }
    /**
     * Represents the step the zoom level will be changed with when using the **ZoomIn** and **ZoomOut** tools.
     * @default 0.25
     */
    zoomRate = 0.25;
    /**
     * Represents minimum allowed zoom value.
     * @default 0.5
     */
    minZoom = 0.5;
    /**
     * Represents maximum allowed zoom value.
     * @default 4
     */
    maxZoom = 4;
    /**
     * Sets whether the component loads all PDF document pages at once or loads new pages on demand when needed.
     *
     * @default false
     */
    loadOnDemand = false;
    /**
     * Sets the number of pages to load on demand when the `loadOnDemand` property is `true`.
     *
     * @default 1
     */
    loadOnDemandPageSize = 1;
    /**
     * Fires when the component loads a PDF document successfully.
     */
    load = new EventEmitter();
    /**
     * Fires when an error occurs while loading or downloading the PDF document.
     */
    error = new EventEmitter();
    /**
     * Fires when the user clicks the **Download** tool of the loaded PDF document.
     */
    download = new EventEmitter();
    /**
     * Fires when the user changes the page of the loaded PDF document.
     */
    pageChange = new EventEmitter();
    /**
     * Fires when the user changes the zoom level of the loaded PDF document.
     */
    zoomLevelChange = new EventEmitter();
    pagesContainer;
    /**
     * Returns the current page number of the loaded PDF document.
     */
    get currentPage() {
        const isDocumentLoaded = this.pagesContainer && this.pdfContext?.pdfDoc;
        return isDocumentLoaded ? this.skip + 1 : null;
    }
    set pdfContext(doc) {
        this._pdfContext = doc;
    }
    /**
     * Exposes the loaded `PDF.js` document, its pages, and their DOM element wrapper.
     */
    get pdfContext() {
        return this._pdfContext;
    }
    /**
     * @hidden
     */
    get activePageId() {
        if (!this.pdfContext?.pdfPages.length) {
            return;
        }
        return this.pagesContainer.nativeElement.querySelectorAll('.k-page')[this.skip]?.getAttribute('id');
    }
    /**
     * @hidden
     */
    get pagesContainerId() {
        if (!this.pdfContext?.pdfPages.length) {
            return;
        }
        return `k-pdfviewer-${counter}-pages-container`;
    }
    loading = false;
    searchActive = false;
    matchCase = false;
    currentMatches = [];
    currentMatch;
    /**
     * @hidden
     */
    set enabledSelection(value) {
        if (this.pdfViewerWidget) {
            value ? this.pdfViewerWidget.documentScroller.disablePanEventsTracking() : this.pdfViewerWidget.documentScroller.enablePanEventsTracking();
        }
        this._enabledSelection = value;
    }
    /**
     * @hidden
     */
    get enabledSelection() {
        return this._enabledSelection;
    }
    /**
     * @hidden
     */
    showLicenseWatermark = false;
    skip = 0;
    zoomOptionsData = zoomOptionsData;
    zoomLevel = this.zoomOptionsData[5];
    _pdfContext = null;
    _enabledSelection = false;
    _zoom = INITIAL_ZOOM_LEVEL;
    _fitType;
    _zoomToFit = false;
    subs = new Subscription();
    emitLoad = true;
    constructor(ngZone, renderer, localizationService, cdr, host) {
        this.ngZone = ngZone;
        this.renderer = renderer;
        this.localizationService = localizationService;
        this.cdr = cdr;
        this.host = host;
        const isValid = validatePackage(packageMetadata);
        this.showLicenseWatermark = shouldShowValidationUI(isValid);
        this.direction = localizationService.rtl ? 'rtl' : 'ltr';
        counter++;
    }
    ngOnInit() {
        this.subs.add(this.localizationService.changes.subscribe(({ rtl }) => this.direction = rtl ? 'rtl' : 'ltr'));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
        this.pdfViewerWidget?.destroy();
        this.pdfContext = null;
    }
    ngOnChanges(changes) {
        const newBase64Data = changes['data'] && this.data;
        const newUrl = changes['url'] && this.url;
        const newArrayBuffer = changes['arrayBuffer'] && this.arrayBuffer;
        const newTypedArray = changes['typedArray'] && this.typedArray;
        this.verifySettings(changes);
        const dataOrTypedArray = newBase64Data ? 'data' : 'typedArray';
        const bufferOrDataOrTypedArray = newArrayBuffer ? 'arrayBuffer' : dataOrTypedArray;
        const source = newUrl ? 'url' : bufferOrDataOrTypedArray;
        if (newUrl || newArrayBuffer || newBase64Data || newTypedArray) {
            this.loadPdf(source, this[source]);
        }
    }
    /**
     * Scrolls the PDFViewer document to the specified page number, treating 0 as the first page
     * ([see example](slug:tools_pdfviewer#programmatically-scrolling-the-pdfviewer)).
     */
    scrollToPage(page) {
        this.pdfViewerWidget?.scrollToPage({ pageNumber: page });
    }
    /**
     * @hidden
     */
    onFileSelect(e) {
        this.loadPdf('data', e);
    }
    /**
     * @hidden
     */
    onFileSelectError(e) {
        this.zoneAwareEmitter('error', { error: e, context: this.pdfContext });
    }
    /**
     * @hidden
     */
    onPageChange(e) {
        this.ngZone.runOutsideAngular(() => this.scrollToPage(e.skip + 1));
    }
    /**
     * @hidden
     */
    onDownload() {
        this.ngZone.runOutsideAngular(() => this.pdfContext.pdfDoc.getData()
            .then((data) => new Blob([data], { type: 'application/pdf' }))
            .then((blob) => {
            const downloadEvent = new PDFViewerDownloadEvent(blob, this.saveFileName, this.saveOptions, this.pdfContext);
            this.zoneAwareEmitter('download', downloadEvent);
            if (!downloadEvent.isDefaultPrevented()) {
                saveAs(blob, this.saveFileName, this.saveOptions);
            }
        })
            .catch((reason) => {
            this.zoneAwareEmitter('error', { error: reason, context: this.pdfContext });
        }));
    }
    /**
     * @hidden
     */
    stopPropagation = (e) => {
        if (e.ctrlKey || e.metaKey) {
            e.preventDefault();
        }
    };
    /**
     * @hidden
     */
    onZoomIn() {
        const newZoom = Math.min(this.zoom + this.zoomRate, this.maxZoom);
        if (newZoom !== this.zoom && this.pdfContext.pdfDoc) {
            this.zoneAwareEmitter('zoomLevelChange', {
                previousZoomLevel: this.zoom,
                currentZoomLevel: newZoom
            });
            this.zoom = this.pdfContext.zoom = newZoom;
        }
    }
    /**
     * @hidden
     */
    onZoomOut() {
        const newZoom = Math.max(this.zoom - this.zoomRate, this.minZoom);
        if (newZoom !== this.zoom && this.pdfContext.pdfDoc) {
            this.zoneAwareEmitter('zoomLevelChange', {
                previousZoomLevel: this.zoom,
                currentZoomLevel: newZoom
            });
            this.zoom = this.pdfContext.zoom = newZoom;
        }
    }
    /**
     * @hidden
     */
    onZoomLevelChange(zoomLevel, emit = true) {
        if (!zoomLevel) {
            zoomLevel = {
                value: 1,
                displayValue: '100%',
                text: '100%'
            };
        }
        let newZoom = zoomLevel.type ? this.pdfViewerWidget?.calculateZoomLevel({
            zoomLevel: zoomLevel.value,
            zoomLevelType: zoomLevel.type,
            currentZoom: this.zoom
        }) : Math.min(Math.max(zoomLevel.value, this.minZoom), this.maxZoom);
        newZoom = Math.round((newZoom + Number.EPSILON) * 100) / 100;
        const sameZoom = this.zoom === newZoom;
        if (!sameZoom) {
            emit && this.zoneAwareEmitter('zoomLevelChange', {
                previousZoomLevel: this.zoom,
                currentZoomLevel: newZoom
            });
            this.zoom = this.pdfContext.zoom = newZoom;
        }
        else {
            this.setZoomLevel(newZoom, zoomLevel.type);
        }
    }
    /**
     * @hidden
     */
    onSearch() {
        this.searchActive = true;
    }
    /**
     * @hidden
     */
    onPrint() {
        this.loading = true;
        this.pdfViewerWidget?.printFile();
    }
    /**
     * @hidden
     */
    onSearchChange(e) {
        this.currentMatches = this.pdfViewerWidget.searchService.search({ ...e });
        this.currentMatch = this.currentMatches.length ? 1 : 0;
    }
    /**
     * @hidden
     */
    closeSearch(toolbar) {
        this.searchActive = false;
        this.pdfViewerWidget.searchService.destroy();
        this.currentMatches = [];
        this.currentMatch = null;
        toolbar.focus();
    }
    /**
     * @hidden
     */
    onNextMatch() {
        this.pdfViewerWidget?.goToNextSearchMatch();
        this.currentMatch = this.currentMatch + 1 > this.currentMatches.length ? 1 : this.currentMatch + 1;
    }
    /**
     * @hidden
     */
    onPreviousMatch() {
        this.pdfViewerWidget?.goToPreviousSearchMatch();
        this.currentMatch = this.currentMatch - 1 < 1 ? this.currentMatches.length : this.currentMatch - 1;
    }
    pdfViewerWidget;
    loadPdf(dataType, data) {
        this.pdfViewerWidget?.destroy();
        this.loading = true;
        this.emitLoad = true;
        this.ngZone.runOutsideAngular(() => {
            // try to destroy if new dynamic data source
            this.pagesContainer && removeChildren(this.pagesContainer.nativeElement);
            const file = dataType === 'url' || dataType === 'data' ? { [dataType]: data } : { data };
            this.pdfViewerWidget = new PdfViewer(this.host.nativeElement, {
                loadOnDemand: this.loadOnDemand,
                loadOnDemandPageSize: this.loadOnDemandPageSize,
                zoomLevel: this.zoom,
                scaleFactor: 1,
                fileDescriptor: file,
                events: {
                    pagesLoad: this.loadHandler,
                    zoomStart: () => {
                        this.skip = this.pdfViewerWidget.getCurrentPageIndex();
                    },
                    zoomEnd: this.zoomEndHandler,
                    printEnd: () => {
                        this.loading = false;
                    },
                    scroll: this.scrollHandler,
                    error: this.errorHandler
                }
            });
        });
    }
    assignPageIds() {
        this.pagesContainer.nativeElement.querySelectorAll('.k-page').forEach((pageElement, index) => {
            const id = `k-pdfviewer-${counter}-page-${index + 1}`;
            this.renderer.setAttribute(pageElement, 'id', id);
        });
    }
    setZoomLevel(zoom, type) {
        const option = this.zoomOptionsData.find(item => (!item.type && item.value === zoom) || (item.type && item.type === type));
        this.zoomLevel = structuredClone(option) ?? {
            value: zoom,
            displayValue: `${Math.round(zoom * 100)}%`,
            text: `${Math.round(zoom * 100)}%`
        };
        this.pdfViewerWidget?.zoom({ zoomLevel: zoom, zoomLevelType: type });
    }
    verifySettings(changes) {
        const sourceTypes = ['url', 'arrayBuffer', 'data', 'typedArray'];
        const setTypes = sourceTypes.map(item => this.isSet(changes, item)).filter(item => item);
        if (isDevMode() && setTypes.length > 1) {
            console.warn(`
                Setting more than one source of data simultaneously is not supported.
                Only one of 'url', 'arrayBuffer', 'data', or 'typedArray' can be set.
            `);
        }
    }
    isSet(changes, source) {
        return this[source] || changes[source]?.currentValue;
    }
    scrollHandler = (e) => {
        const currentPage = this.currentPage;
        this.skip = e.pageNumber - 1;
        this.cdr.markForCheck();
        if (e.isPageChanged) {
            this.zoneAwareEmitter('pageChange', {
                previousPage: currentPage,
                currentPage: e.pageNumber
            });
        }
    };
    loadHandler = (e) => {
        if (!this.pdfContext) {
            this.pdfViewerWidget.documentScroller.enablePanEventsTracking();
        }
        if (!this._zoomToFit) {
            this.pdfContext = { ...e, element: this.pagesContainer.nativeElement, zoom: e.sender.state.zoomLevel };
            if (this.emitLoad) {
                this.zoneAwareEmitter('load', { context: this.pdfContext });
                this.emitLoad = false;
            }
        }
        else {
            const zoomLevelOption = this.zoomOptionsData.find(item => item.type === this._fitType);
            this.pdfContext = { ...e, element: this.pagesContainer.nativeElement };
            this.onZoomLevelChange(zoomLevelOption, false);
        }
        this.cdr.markForCheck();
        this.assignPageIds();
        this.ngZone.run(() => this.loading = false);
    };
    zoomEndHandler = (e) => {
        const zoom = Math.round(Math.min(Math.max(e.zoomLevel, this.minZoom), this.maxZoom) * 100) / 100;
        this.zoneAwareEmitter('zoomLevelChange', {
            currentZoomLevel: zoom,
            previousZoomLevel: this.zoom
        });
        this.zoom = zoom;
    };
    errorHandler = (e) => {
        this.ngZone.run(() => this.loading = false);
        this.pdfContext = null;
        this.zoneAwareEmitter('error', { error: e, context: this.pdfContext });
    };
    zoneAwareEmitter = (eventName, eventData) => {
        if (hasObservers(this[eventName])) {
            this.ngZone.run(() => this[eventName].emit(eventData));
        }
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerComponent, deps: [{ token: i0.NgZone }, { token: i0.Renderer2 }, { token: i1.LocalizationService }, { token: i0.ChangeDetectorRef }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: PDFViewerComponent, isStandalone: true, selector: "kendo-pdfviewer", inputs: { tools: "tools", loaderSettings: "loaderSettings", saveFileName: "saveFileName", saveOptions: "saveOptions", url: "url", data: "data", arrayBuffer: "arrayBuffer", typedArray: "typedArray", zoom: "zoom", zoomRate: "zoomRate", minZoom: "minZoom", maxZoom: "maxZoom", loadOnDemand: "loadOnDemand", loadOnDemandPageSize: "loadOnDemandPageSize" }, outputs: { load: "load", error: "error", download: "download", pageChange: "pageChange", zoomLevelChange: "zoomLevelChange" }, host: { properties: { "class.k-pdf-viewer": "this.hostClass", "attr.dir": "this.direction" } }, providers: [
            LocalizationService,
            {
                provide: L10N_PREFIX,
                useValue: 'kendo.pdfviewer'
            }
        ], viewQueries: [{ propertyName: "pagesContainer", first: true, predicate: ["pagesContainer"], descendants: true }], exportAs: ["kendo-pdfviewer"], usesOnChanges: true, ngImport: i0, template: `
        <ng-container kendoPDFViewerLocalizedMessages
            i18n-pagerFirstPage="kendo.pdfviewer.pagerFirstPage|The label for the first page button in the Pager"
            pagerFirstPage="Go to the first page"

            i18n-pagerPreviousPage="kendo.pdfviewer.pagerPreviousPage|The label for the previous page button in the Pager"
            pagerPreviousPage="Go to the previous page"

            i18n-pagerNextPage="kendo.pdfviewer.pagerNextPage|The label for the next page button in the Pager"
            pagerNextPage="Go to the next page"

            i18n-pagerLastPage="kendo.pdfviewer.pagerLastPage|The label for the last page button in the Pager"
            pagerLastPage="Go to the last page"

            i18n-pagerPage="kendo.pdfviewer.pagerPage|The text before the current page number in the Pager"
            pagerPage="Page"

            i18n-pagerOf="kendo.pdfviewer.pagerOf|The text before the total pages number in the Pager"
            pagerOf="of"

            i18n-pagerInputTitle="kendo.pdfviewer.pagerInputTitle|The label of the pager input element"
            pagerInputTitle="Page Number"

            i18n-pagerInputLabel="kendo.pdfviewer.pagerInputLabel|The text of the aria-label attribute applied to the input element for entering the page number."
            pagerInputLabel="Type a page number"
            
            i18n-zoomInTitle="kendo.pdfviewer.zoomInTitle|The ZoomIn tool title and label."
            zoomInTitle="Zoom in"
            
            i18n-zoomOutTitle="kendo.pdfviewer.zoomOutTitle|The ZoomOut tool title and label."
            zoomOutTitle="Zoom out"
            
            i18n-selectionTitle="kendo.pdfviewer.selectionTitle|The Selection tool title and label."
            selectionTitle="Enable selection"
            
            i18n-panningTitle="kendo.pdfviewer.panningTitle|The Panning tool title and label."
            panningTitle="Enable panning"
            
            i18n-searchTitle="kendo.pdfviewer.searchTitle|The Search tool title and label."
            searchTitle="Search"
            
            i18n-openTitle="kendo.pdfviewer.openTitle|The Open tool title and label."
            openTitle="Open"
            
            i18n-downloadTitle="kendo.pdfviewer.downloadTitle|The Download tool title and label."
            downloadTitle="Download"
            
            i18n-printTitle="kendo.pdfviewer.printTitle|The Print tool title and label."
            printTitle="Print"
            
            i18n-fitToPage="kendo.pdfviewer.fitToPage|The text for the zoom level chooser Fit to page option."
            fitToPage="Fit to page"
            
            i18n-fitToWidth="kendo.pdfviewer.fitToWidth|The text for the zoom level chooser Fit to width option."
            fitToWidth="Fit to width"
            
            i18n-searchInputPlaceholder="kendo.pdfviewer.searchInputPlaceholder|The text for the search input placeholder."
            searchInputPlaceholder="Search"
            
            i18n-searchMatchesOf="kendo.pdfviewer.searchMatchesOf|The text before the total number of matches in the Search tool."
            searchMatchesOf="of"
            
            i18n-searchPreviousMatchTitle="kendo.pdfviewer.searchPreviousMatchTitle|The title of the Search tool previous match button."
            searchPreviousMatchTitle="Previous match"
            
            i18n-searchNextMatchTitle="kendo.pdfviewer.searchNextMatchTitle|The title of the Search tool next match button."
            searchNextMatchTitle="Next match"
            
            i18n-searchCloseTitle="kendo.pdfviewer.searchCloseTitle|The title of the Search tool close button."
            searchCloseTitle="Close"
            
            i18n-searchMatchCaseTitle="kendo.pdfviewer.searchMatchCaseTitle|The title of the Search tool match case button."
            searchMatchCaseTitle="Match case"
            
            i18n-zoomInputPlaceholder="kendo.pdfviewer.zoomInputPlaceholder|The text for the zoom tool input placeholder."
            zoomInputPlaceholder="Choose zoom level">
        </ng-container>
        <div kendoPDFViewerLoader 
            *ngIf="loading"
            [settings]="loaderSettings"></div>
        <div kendoPDFViewerToolbar
            #toolbar
            role="toolbar"
            [attr.aria-controls]="pagesContainerId"
            [tools]="tools"
            [skip]="skip"
            [total]="pdfContext?.pdfPages.length ? pdfContext?.pdfPages.length : 1"
            [pageSize]="1"
            [zoomInDisabled]="zoom >= maxZoom || !pdfContext?.pdfDoc"
            [zoomOutDisabled]="zoom <= minZoom || !pdfContext?.pdfDoc"
            [zoomOptionsData]="zoomOptionsData"
            [zoomLevelChooserValue]="zoomLevel"
            [disabledTools]="!pdfContext?.pdfDoc"
            (pageChange)="onPageChange($event)"
            (fileSelect)="onFileSelect($event)"
            (fileSelectStart)="loading = true;"
            (fileSelectError)="onFileSelectError($event)"
            (download)="onDownload()"
            (panningEnabled)="enabledSelection = false;"
            (selectionEnabled)="enabledSelection = true;"
            (zoomIn)="onZoomIn()"
            (zoomOut)="onZoomOut()"
            (zoomLevelChange)="onZoomLevelChange($event)"
            (print)="onPrint()"
            (search)="onSearch()"></div>
        <div
            class="k-canvas k-pdf-viewer-canvas k-pos-relative k-overflow-auto"
            [class.k-enable-text-select]="enabledSelection"
            [class.k-enable-panning]="!enabledSelection"
            [attr.aria-describedby]="activePageId"
            tabindex="0">
            <div
                kendoPDFViewerSearch
                *ngIf="searchActive"
                [currentMatch]="currentMatch"
                [matches]="currentMatches.length"
                class="k-search-panel k-pos-sticky k-top-center"
                (searchChange)="onSearchChange($event)"
                (prevMatch)="onPreviousMatch()"
                (nextMatch)="onNextMatch()"
                (close)="closeSearch(toolbar)"></div>
            <div 
                #pagesContainer
                [kendoEventsOutsideAngular]="{
                    wheel: stopPropagation
                }"
                class="k-pdf-viewer-pages"
                [attr.id]="pagesContainerId"></div>
        </div>

        <div kendoWatermarkOverlay *ngIf="showLicenseWatermark"></div>
    `, isInline: true, dependencies: [{ kind: "directive", type: LocalizedPDFViewerMessagesDirective, selector: "[kendoPDFViewerLocalizedMessages]" }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: EventsOutsideAngularDirective, selector: "[kendoEventsOutsideAngular]", inputs: ["kendoEventsOutsideAngular", "scope"] }, { kind: "component", type: LoaderComponent, selector: "[kendoPDFViewerLoader]", inputs: ["settings"] }, { kind: "component", type: ToolbarComponent, selector: "[kendoPDFViewerToolbar]", inputs: ["zoomLevel", "calculatedComboBoxValue", "skip", "pageSize", "total", "zoomInDisabled", "zoomOutDisabled", "disabledTools", "zoomLevelChooserValue", "zoomOptionsData", "pagesContainerId", "tools"], outputs: ["fileSelect", "fileSelectStart", "fileSelectError", "download", "selectionEnabled", "panningEnabled", "pageChange", "zoomIn", "zoomOut", "zoomLevelChange", "print", "search"] }, { kind: "component", type: PDFViewerSearchComponent, selector: "[kendoPDFViewerSearch]", inputs: ["matches", "currentMatch"], outputs: ["searchChange", "prevMatch", "nextMatch", "close"] }, { kind: "component", type: WatermarkOverlayComponent, selector: "div[kendoWatermarkOverlay]" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerComponent, decorators: [{
            type: Component,
            args: [{
                    exportAs: 'kendo-pdfviewer',
                    selector: 'kendo-pdfviewer',
                    providers: [
                        LocalizationService,
                        {
                            provide: L10N_PREFIX,
                            useValue: 'kendo.pdfviewer'
                        }
                    ],
                    template: `
        <ng-container kendoPDFViewerLocalizedMessages
            i18n-pagerFirstPage="kendo.pdfviewer.pagerFirstPage|The label for the first page button in the Pager"
            pagerFirstPage="Go to the first page"

            i18n-pagerPreviousPage="kendo.pdfviewer.pagerPreviousPage|The label for the previous page button in the Pager"
            pagerPreviousPage="Go to the previous page"

            i18n-pagerNextPage="kendo.pdfviewer.pagerNextPage|The label for the next page button in the Pager"
            pagerNextPage="Go to the next page"

            i18n-pagerLastPage="kendo.pdfviewer.pagerLastPage|The label for the last page button in the Pager"
            pagerLastPage="Go to the last page"

            i18n-pagerPage="kendo.pdfviewer.pagerPage|The text before the current page number in the Pager"
            pagerPage="Page"

            i18n-pagerOf="kendo.pdfviewer.pagerOf|The text before the total pages number in the Pager"
            pagerOf="of"

            i18n-pagerInputTitle="kendo.pdfviewer.pagerInputTitle|The label of the pager input element"
            pagerInputTitle="Page Number"

            i18n-pagerInputLabel="kendo.pdfviewer.pagerInputLabel|The text of the aria-label attribute applied to the input element for entering the page number."
            pagerInputLabel="Type a page number"
            
            i18n-zoomInTitle="kendo.pdfviewer.zoomInTitle|The ZoomIn tool title and label."
            zoomInTitle="Zoom in"
            
            i18n-zoomOutTitle="kendo.pdfviewer.zoomOutTitle|The ZoomOut tool title and label."
            zoomOutTitle="Zoom out"
            
            i18n-selectionTitle="kendo.pdfviewer.selectionTitle|The Selection tool title and label."
            selectionTitle="Enable selection"
            
            i18n-panningTitle="kendo.pdfviewer.panningTitle|The Panning tool title and label."
            panningTitle="Enable panning"
            
            i18n-searchTitle="kendo.pdfviewer.searchTitle|The Search tool title and label."
            searchTitle="Search"
            
            i18n-openTitle="kendo.pdfviewer.openTitle|The Open tool title and label."
            openTitle="Open"
            
            i18n-downloadTitle="kendo.pdfviewer.downloadTitle|The Download tool title and label."
            downloadTitle="Download"
            
            i18n-printTitle="kendo.pdfviewer.printTitle|The Print tool title and label."
            printTitle="Print"
            
            i18n-fitToPage="kendo.pdfviewer.fitToPage|The text for the zoom level chooser Fit to page option."
            fitToPage="Fit to page"
            
            i18n-fitToWidth="kendo.pdfviewer.fitToWidth|The text for the zoom level chooser Fit to width option."
            fitToWidth="Fit to width"
            
            i18n-searchInputPlaceholder="kendo.pdfviewer.searchInputPlaceholder|The text for the search input placeholder."
            searchInputPlaceholder="Search"
            
            i18n-searchMatchesOf="kendo.pdfviewer.searchMatchesOf|The text before the total number of matches in the Search tool."
            searchMatchesOf="of"
            
            i18n-searchPreviousMatchTitle="kendo.pdfviewer.searchPreviousMatchTitle|The title of the Search tool previous match button."
            searchPreviousMatchTitle="Previous match"
            
            i18n-searchNextMatchTitle="kendo.pdfviewer.searchNextMatchTitle|The title of the Search tool next match button."
            searchNextMatchTitle="Next match"
            
            i18n-searchCloseTitle="kendo.pdfviewer.searchCloseTitle|The title of the Search tool close button."
            searchCloseTitle="Close"
            
            i18n-searchMatchCaseTitle="kendo.pdfviewer.searchMatchCaseTitle|The title of the Search tool match case button."
            searchMatchCaseTitle="Match case"
            
            i18n-zoomInputPlaceholder="kendo.pdfviewer.zoomInputPlaceholder|The text for the zoom tool input placeholder."
            zoomInputPlaceholder="Choose zoom level">
        </ng-container>
        <div kendoPDFViewerLoader 
            *ngIf="loading"
            [settings]="loaderSettings"></div>
        <div kendoPDFViewerToolbar
            #toolbar
            role="toolbar"
            [attr.aria-controls]="pagesContainerId"
            [tools]="tools"
            [skip]="skip"
            [total]="pdfContext?.pdfPages.length ? pdfContext?.pdfPages.length : 1"
            [pageSize]="1"
            [zoomInDisabled]="zoom >= maxZoom || !pdfContext?.pdfDoc"
            [zoomOutDisabled]="zoom <= minZoom || !pdfContext?.pdfDoc"
            [zoomOptionsData]="zoomOptionsData"
            [zoomLevelChooserValue]="zoomLevel"
            [disabledTools]="!pdfContext?.pdfDoc"
            (pageChange)="onPageChange($event)"
            (fileSelect)="onFileSelect($event)"
            (fileSelectStart)="loading = true;"
            (fileSelectError)="onFileSelectError($event)"
            (download)="onDownload()"
            (panningEnabled)="enabledSelection = false;"
            (selectionEnabled)="enabledSelection = true;"
            (zoomIn)="onZoomIn()"
            (zoomOut)="onZoomOut()"
            (zoomLevelChange)="onZoomLevelChange($event)"
            (print)="onPrint()"
            (search)="onSearch()"></div>
        <div
            class="k-canvas k-pdf-viewer-canvas k-pos-relative k-overflow-auto"
            [class.k-enable-text-select]="enabledSelection"
            [class.k-enable-panning]="!enabledSelection"
            [attr.aria-describedby]="activePageId"
            tabindex="0">
            <div
                kendoPDFViewerSearch
                *ngIf="searchActive"
                [currentMatch]="currentMatch"
                [matches]="currentMatches.length"
                class="k-search-panel k-pos-sticky k-top-center"
                (searchChange)="onSearchChange($event)"
                (prevMatch)="onPreviousMatch()"
                (nextMatch)="onNextMatch()"
                (close)="closeSearch(toolbar)"></div>
            <div 
                #pagesContainer
                [kendoEventsOutsideAngular]="{
                    wheel: stopPropagation
                }"
                class="k-pdf-viewer-pages"
                [attr.id]="pagesContainerId"></div>
        </div>

        <div kendoWatermarkOverlay *ngIf="showLicenseWatermark"></div>
    `,
                    standalone: true,
                    imports: [LocalizedPDFViewerMessagesDirective, NgIf, EventsOutsideAngularDirective, LoaderComponent, ToolbarComponent, PDFViewerSearchComponent, WatermarkOverlayComponent]
                }]
        }], ctorParameters: function () { return [{ type: i0.NgZone }, { type: i0.Renderer2 }, { type: i1.LocalizationService }, { type: i0.ChangeDetectorRef }, { type: i0.ElementRef }]; }, propDecorators: { hostClass: [{
                type: HostBinding,
                args: ['class.k-pdf-viewer']
            }], direction: [{
                type: HostBinding,
                args: ['attr.dir']
            }], tools: [{
                type: Input
            }], loaderSettings: [{
                type: Input
            }], saveFileName: [{
                type: Input
            }], saveOptions: [{
                type: Input
            }], url: [{
                type: Input
            }], data: [{
                type: Input
            }], arrayBuffer: [{
                type: Input
            }], typedArray: [{
                type: Input
            }], zoom: [{
                type: Input
            }], zoomRate: [{
                type: Input
            }], minZoom: [{
                type: Input
            }], maxZoom: [{
                type: Input
            }], loadOnDemand: [{
                type: Input
            }], loadOnDemandPageSize: [{
                type: Input
            }], load: [{
                type: Output
            }], error: [{
                type: Output
            }], download: [{
                type: Output
            }], pageChange: [{
                type: Output
            }], zoomLevelChange: [{
                type: Output
            }], pagesContainer: [{
                type: ViewChild,
                args: ['pagesContainer']
            }] } });
