/**-----------------------------------------------------------------------------------------
* Copyright © 2025 Progress Software Corporation. All rights reserved.
* Licensed under commercial license. See LICENSE.md in the project root for more information
*-------------------------------------------------------------------------------------------*/
import * as i0 from '@angular/core';
import { Directive, Input, forwardRef, Component, Injectable, HostBinding, EventEmitter, ViewChild, Output, ElementRef, HostListener, isDevMode, NgModule } from '@angular/core';
import * as i1 from '@progress/kendo-angular-l10n';
import { ComponentMessages, LocalizationService, L10N_PREFIX } from '@progress/kendo-angular-l10n';
import { validatePackage } from '@progress/kendo-licensing';
import { removeChildren, PdfViewer } from '@progress/kendo-pdfviewer-common';
import { PreventableEvent, Keys, focusableSelector, shouldShowValidationUI, hasObservers, EventsOutsideAngularDirective, WatermarkOverlayComponent, ResizeBatchService } from '@progress/kendo-angular-common';
import { saveAs } from '@progress/kendo-file-saver';
import { Subscription } from 'rxjs';
import { PagerComponent, CustomMessagesComponent } from '@progress/kendo-angular-pager';
import { zoomInIcon, zoomOutIcon, handIcon, pointerIcon, searchIcon, folderOpenIcon, downloadIcon, printIcon, convertLowercaseIcon, arrowUpIcon, arrowDownIcon, xIcon } from '@progress/kendo-svg-icons';
import * as i1$1 from '@progress/kendo-angular-dropdowns';
import { ComboBoxComponent, ItemTemplateDirective } from '@progress/kendo-angular-dropdowns';
import { ButtonGroupComponent, ButtonComponent } from '@progress/kendo-angular-buttons';
import { NgFor, NgSwitch, NgSwitchCase, NgIf } from '@angular/common';
import { map } from 'rxjs/operators';
import { TextBoxComponent, TextBoxSuffixTemplateDirective } from '@progress/kendo-angular-inputs';
import { LoaderComponent as LoaderComponent$1 } from '@progress/kendo-angular-indicators';
import 'pdfjs-dist/build/pdf.worker.min.mjs';
import { IconsService } from '@progress/kendo-angular-icons';
import { PopupService } from '@progress/kendo-angular-popup';

/**
 * @hidden
 */
class Messages extends ComponentMessages {
    /**
     * Sets the title and label for the **ZoomIn** tool.
     */
    zoomInTitle;
    /**
     * Sets the title and label for the **ZoomOut** tool.
     */
    zoomOutTitle;
    /**
     * Sets the title and label for the **Selection** tool.
     */
    selectionTitle;
    /**
     * Sets the title and label for the **Panning** tool.
     */
    panningTitle;
    /**
     * Sets the title and label for the **Search** tool.
     */
    searchTitle;
    /**
     * Sets the title and label for the **Open** tool.
     */
    openTitle;
    /**
     * Sets the title and label for the **Download** tool.
     */
    downloadTitle;
    /**
     * Sets the title and label for the **Print** tool.
     */
    printTitle;
    /**
     * Sets the `aria-label` attribute for the Pager input element.
     */
    pagerInputLabel;
    /**
     * Sets the `title` attribute for the Pager input element.
     */
    pagerInputTitle;
    /**
     * Sets the label for the Pager **First page** button.
     */
    pagerFirstPage;
    /**
     * Sets the label for the Pager **Previous page** button.
     */
    pagerPreviousPage;
    /**
     * Sets the label for the Pager **Next page** button.
     */
    pagerNextPage;
    /**
     * Sets the label for the Pager **Last page** button.
     */
    pagerLastPage;
    /**
     * Sets the text before the Pager total-page number.
     */
    pagerOf;
    /**
     * Sets the text before the Pager input.
     */
    pagerPage;
    /**
     * Sets the text for the zoom level chooser **Fit to page** option.
     */
    fitToPage;
    /**
     * Sets the text for the zoom level chooser **Fit to width** option.
     */
    fitToWidth;
    /**
     * Sets the placeholder text for the search input.
     */
    searchInputPlaceholder;
    /**
     * Sets the text before the total number of matches in the **Search** tool.
     */
    searchMatchesOf;
    /**
     * Sets the title for the **Search** previous match button.
     */
    searchPreviousMatchTitle;
    /**
     * Sets the title for the **Search** next match button.
     */
    searchNextMatchTitle;
    /**
     * Sets the title for the **Search** close button.
     */
    searchCloseTitle;
    /**
     * Sets the title for the **Search** match case button.
     */
    searchMatchCaseTitle;
    /**
     * Sets the placeholder text for the zoom tool input.
     */
    zoomInputPlaceholder;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages, deps: null, target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: Messages, selector: "kendo-pdfviewer-messages-base", inputs: { zoomInTitle: "zoomInTitle", zoomOutTitle: "zoomOutTitle", selectionTitle: "selectionTitle", panningTitle: "panningTitle", searchTitle: "searchTitle", openTitle: "openTitle", downloadTitle: "downloadTitle", printTitle: "printTitle", pagerInputLabel: "pagerInputLabel", pagerInputTitle: "pagerInputTitle", pagerFirstPage: "pagerFirstPage", pagerPreviousPage: "pagerPreviousPage", pagerNextPage: "pagerNextPage", pagerLastPage: "pagerLastPage", pagerOf: "pagerOf", pagerPage: "pagerPage", fitToPage: "fitToPage", fitToWidth: "fitToWidth", searchInputPlaceholder: "searchInputPlaceholder", searchMatchesOf: "searchMatchesOf", searchPreviousMatchTitle: "searchPreviousMatchTitle", searchNextMatchTitle: "searchNextMatchTitle", searchCloseTitle: "searchCloseTitle", searchMatchCaseTitle: "searchMatchCaseTitle", zoomInputPlaceholder: "zoomInputPlaceholder" }, usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: Messages, decorators: [{
            type: Directive,
            args: [{
                    // eslint-disable-next-line @angular-eslint/directive-selector
                    selector: 'kendo-pdfviewer-messages-base'
                }]
        }], propDecorators: { zoomInTitle: [{
                type: Input
            }], zoomOutTitle: [{
                type: Input
            }], selectionTitle: [{
                type: Input
            }], panningTitle: [{
                type: Input
            }], searchTitle: [{
                type: Input
            }], openTitle: [{
                type: Input
            }], downloadTitle: [{
                type: Input
            }], printTitle: [{
                type: Input
            }], pagerInputLabel: [{
                type: Input
            }], pagerInputTitle: [{
                type: Input
            }], pagerFirstPage: [{
                type: Input
            }], pagerPreviousPage: [{
                type: Input
            }], pagerNextPage: [{
                type: Input
            }], pagerLastPage: [{
                type: Input
            }], pagerOf: [{
                type: Input
            }], pagerPage: [{
                type: Input
            }], fitToPage: [{
                type: Input
            }], fitToWidth: [{
                type: Input
            }], searchInputPlaceholder: [{
                type: Input
            }], searchMatchesOf: [{
                type: Input
            }], searchPreviousMatchTitle: [{
                type: Input
            }], searchNextMatchTitle: [{
                type: Input
            }], searchCloseTitle: [{
                type: Input
            }], searchMatchCaseTitle: [{
                type: Input
            }], zoomInputPlaceholder: [{
                type: Input
            }] } });

/**
 * Represents the custom messages component of the PDFViewer.
 *
 * Use this component to override default messages for the PDFViewer.
 *
 * @example
 * ```html
 * <kendo-pdfviewer [url]="pdfUrl">
 *   <kendo-pdfviewer-messages
 *       downloadTitle="Download PDF"
 *       printTitle="Print PDF">
 *   </kendo-pdfviewer-messages>
 * </kendo-pdfviewer>
 * ```
 */
class PDFViewerCustomMessagesComponent extends Messages {
    service;
    constructor(service) {
        super();
        this.service = service;
    }
    get override() {
        return true;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerCustomMessagesComponent, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: PDFViewerCustomMessagesComponent, isStandalone: true, selector: "kendo-pdfviewer-messages", providers: [{
                provide: Messages,
                useExisting: forwardRef(() => PDFViewerCustomMessagesComponent)
            }], usesInheritance: true, ngImport: i0, template: ``, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerCustomMessagesComponent, decorators: [{
            type: Component,
            args: [{
                    providers: [{
                            provide: Messages,
                            useExisting: forwardRef(() => PDFViewerCustomMessagesComponent)
                        }],
                    selector: 'kendo-pdfviewer-messages',
                    template: ``,
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; } });

/**
 * @hidden
 */
const packageMetadata = {
    name: '@progress/kendo-angular-pdfviewer',
    productName: 'Kendo UI for Angular',
    productCode: 'KENDOUIANGULAR',
    productCodes: ['KENDOUIANGULAR'],
    publishDate: 1751463378,
    version: '19.2.0',
    licensingDocsUrl: 'https://www.telerik.com/kendo-angular-ui/my-license/?utm_medium=product&utm_source=kendoangular&utm_campaign=kendo-ui-angular-purchase-license-keys-warning',
};

/**
 * @hidden
 */
const INITIAL_ZOOM_LEVEL = 1.25;
/**
 * @hidden
 */
const MIN_ZOOM_LEVEL = 0.5;
/**
 * @hidden
 */
const MAX_ZOOM_LEVEL = 4;
/**
 * @hidden
 */
const zoomOptionsData = [{
        id: 1,
        text: 'Fit to width',
        type: 'FitToWidth',
        displayValue: 'Fit to width',
        value: 1
    }, {
        id: 2,
        text: 'Fit to page',
        type: 'FitToPage',
        displayValue: 'Fit to page',
        value: 1
    }, {
        id: 3,
        text: '50%',
        displayValue: '50%',
        value: 0.5
    }, {
        id: 4,
        text: '75%',
        displayValue: '75%',
        value: 0.75
    }, {
        id: 5,
        text: '100%',
        displayValue: '100%',
        value: 1
    }, {
        id: 6,
        text: '125%',
        displayValue: '125%',
        value: 1.25
    }, {
        id: 7,
        text: '150%',
        displayValue: '150%',
        value: 1.5
    }, {
        id: 8,
        text: '200%',
        displayValue: '200%',
        value: 2
    }, {
        id: 9,
        text: '300%',
        displayValue: '300%',
        value: 3
    }, {
        id: 10,
        text: '400%',
        displayValue: '400%',
        value: 4
    }];
/**
 * @hidden
 */
const zoomToFitOptions = {
    'fitToPage': 'FitToPage',
    'fitToWidth': 'FitToWidth'
};

/**
 * Represents the arguments for the PDFViewer `download` event. The event fires when the user clicks the **Download** tool. Canceling the event prevents the download.
 */
class PDFViewerDownloadEvent extends PreventableEvent {
    /**
     * Provides the Blob object to be saved.
     */
    blob;
    /**
     * Provides the file name for saving.
     */
    fileName;
    /**
     * Provides the save options.
     */
    saveOptions;
    /**
     * Represents the loaded `PDF.js` document, its pages, and their DOM element wrapper.
     */
    context;
    /**
     * @hidden
     */
    constructor(blob, fileName, saveOptions, context) {
        super();
        this.blob = blob;
        this.fileName = fileName;
        this.saveOptions = saveOptions;
        this.context = context;
    }
}

/**
 * @hidden
 */
class ToolbarNavigationService {
    localizationService;
    focusableTools = [];
    currentFocusIndex = 0;
    constructor(localizationService) {
        this.localizationService = localizationService;
    }
    register(tool) {
        if (!this.focusableTools.some(el => el === tool)) {
            this.focusableTools.push(tool);
        }
    }
    unregister(tool) {
        this.currentFocusIndex = 0;
        this.focusableTools = this.focusableTools.filter(el => el !== tool);
    }
    isActive(focusable) {
        return this.focusableTools[this.currentFocusIndex] === focusable;
    }
    setActiveIndex(tool) {
        this.currentFocusIndex = Math.max(this.focusableTools.indexOf(tool), 0);
    }
    move(direction) {
        let delta = direction === 'right' ? 1 : -1;
        if (this.localizationService.rtl) {
            delta = -delta;
        }
        this.currentFocusIndex += delta;
        if (this.currentFocusIndex < 0) {
            this.currentFocusIndex = this.focusableTools.length - 1;
        }
        else if (this.currentFocusIndex >= this.focusableTools.length) {
            this.currentFocusIndex = 0;
        }
        this.focusableTools[this.currentFocusIndex].activate();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarNavigationService, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Injectable });
    static ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarNavigationService });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarNavigationService, decorators: [{
            type: Injectable
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; } });

/**
 * @hidden
 */
class ToolbarComboBoxDirective {
    combo;
    hostEl;
    inputElement;
    constructor(combo, hostEl) {
        this.combo = combo;
        this.hostEl = hostEl;
    }
    ngAfterViewInit() {
        this.inputElement = this.combo.searchbar.input.nativeElement;
        this.hostEl.nativeElement.setAttribute('tabindex', '-1');
        this.inputElement.addEventListener('keydown', this.keydownHandler, true);
    }
    ngOnDestroy() {
        this.inputElement.removeEventListener('keydown', this.keydownHandler);
    }
    keydownHandler = (e) => {
        if (e.keyCode === Keys.Escape) {
            e.stopPropagation();
            if (this.combo.isOpen) {
                this.combo.toggle(false);
            }
            else {
                this.hostEl.nativeElement.parentElement.focus();
            }
        }
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarComboBoxDirective, deps: [{ token: i1$1.ComboBoxComponent }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: ToolbarComboBoxDirective, isStandalone: true, selector: "[kendoPDFViewerComboBox]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarComboBoxDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoPDFViewerComboBox]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1$1.ComboBoxComponent }, { type: i0.ElementRef }]; } });

const controller = new AbortController();
const { signal } = controller;
/**
 * @hidden
 */
class ToolbarFocusableDirective {
    host;
    navigationService;
    renderer;
    constructor(host, navigationService, renderer) {
        this.host = host;
        this.navigationService = navigationService;
        this.renderer = renderer;
        navigationService.register(this);
    }
    ngAfterViewInit() {
        const element = this.host.nativeElement;
        this.renderer.setAttribute(element, 'tabindex', this.navigationService.isActive(this) ? '0' : '-1');
        element.addEventListener('keydown', (e) => {
            const targetsSelf = e.target === element;
            const isLeftArrow = e.keyCode === Keys.ArrowLeft;
            const isRightArrow = e.keyCode === Keys.ArrowRight;
            const isArrow = isLeftArrow || isRightArrow;
            if (!targetsSelf || !isArrow) {
                return;
            }
            this.renderer.setAttribute(element, 'tabindex', '-1');
            element.querySelectorAll(focusableSelector).forEach(el => {
                this.renderer.setAttribute(el, 'tabindex', '-1');
            });
            if (isRightArrow) {
                this.navigationService.move('right');
            }
            else if (isLeftArrow) {
                this.navigationService.move('left');
            }
        }, { signal, capture: true });
        element.addEventListener('click', () => {
            this.navigationService.setActiveIndex(this);
        }, { signal, capture: true });
    }
    ngOnDestroy() {
        controller.abort();
        this.navigationService.unregister(this);
    }
    activate() {
        const element = this.host.nativeElement;
        this.renderer.setAttribute(element, 'tabindex', '0');
        element.focus();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarFocusableDirective, deps: [{ token: i0.ElementRef }, { token: ToolbarNavigationService }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: ToolbarFocusableDirective, isStandalone: true, selector: "[kendoPDFViewerToolbarFocusable]", ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarFocusableDirective, decorators: [{
            type: Directive,
            args: [{
                    selector: '[kendoPDFViewerToolbarFocusable]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: ToolbarNavigationService }, { type: i0.Renderer2 }]; } });

/**
 * @hidden
 */
class ToolbarInputWrapperComponent {
    host;
    renderer;
    toolbarTool;
    hostClass = true;
    subs = new Subscription();
    constructor(host, renderer) {
        this.host = host;
        this.renderer = renderer;
    }
    ngAfterViewInit() {
        this.subs.add(this.renderer.listen(this.host.nativeElement, 'keydown.enter', () => {
            if (this.toolbarTool.focus) {
                this.toolbarTool.focus();
            }
            else if (this.toolbarTool.element) {
                this.toolbarTool.element.nativeElement.setAttribute('tabindex', '0');
                this.toolbarTool.element.nativeElement.focus();
            }
        }));
        this.subs.add(this.renderer.listen(this.host.nativeElement, 'blur', () => this.host.nativeElement.querySelectorAll(focusableSelector).forEach(el => el.setAttribute('tabindex', '-1'))));
        this.subs.add(this.renderer.listen(this.host.nativeElement, 'keydown.escape', () => {
            if (this.toolbarTool.blur) {
                this.toolbarTool.blur();
            }
            else if (this.toolbarTool.element) {
                this.toolbarTool.element.nativeElement.setAttribute('tabindex', '-1');
                this.toolbarTool.element.nativeElement.blur();
            }
            this.host.nativeElement.focus();
        }));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarInputWrapperComponent, deps: [{ token: i0.ElementRef }, { token: i0.Renderer2 }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ToolbarInputWrapperComponent, isStandalone: true, selector: "kendo-toolbar-input-wrapper", inputs: { toolbarTool: "toolbarTool" }, host: { properties: { "class.k-toolbar-item": "this.hostClass" } }, ngImport: i0, template: `
        <ng-content></ng-content>
    `, isInline: true });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarInputWrapperComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'kendo-toolbar-input-wrapper',
                    template: `
        <ng-content></ng-content>
    `,
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i0.ElementRef }, { type: i0.Renderer2 }]; }, propDecorators: { toolbarTool: [{
                type: Input
            }], hostClass: [{
                type: HostBinding,
                args: ['class.k-toolbar-item']
            }] } });

/* eslint-disable @typescript-eslint/no-empty-function */
/**
 * @hidden
 */
class ToolbarComponent {
    localization;
    navigationService;
    toolbarClasses = true;
    fileSelectEl;
    zoomLevel = {
        text: '125%',
        displayValue: '125%',
        value: 1.25
    };
    calculatedComboBoxValue = {
        text: 'Fit to width',
        displayValue: null,
        value: null
    };
    skip = 0;
    pageSize = 1;
    total;
    zoomInDisabled;
    zoomOutDisabled;
    disabledTools;
    zoomLevelChooserValue;
    zoomOptionsData;
    pagesContainerId;
    tools;
    fileSelect = new EventEmitter();
    fileSelectStart = new EventEmitter();
    fileSelectError = new EventEmitter();
    download = new EventEmitter();
    selectionEnabled = new EventEmitter();
    panningEnabled = new EventEmitter();
    pageChange = new EventEmitter();
    zoomIn = new EventEmitter();
    zoomOut = new EventEmitter();
    zoomLevelChange = new EventEmitter();
    print = new EventEmitter();
    search = new EventEmitter();
    zoomInIcon = zoomInIcon;
    zoomOutIcon = zoomOutIcon;
    handIcon = handIcon;
    pointerIcon = pointerIcon;
    searchIcon = searchIcon;
    folderOpenIcon = folderOpenIcon;
    downloadIcon = downloadIcon;
    printIcon = printIcon;
    pagerType = 'input';
    constructor(localization, navigationService) {
        this.localization = localization;
        this.navigationService = navigationService;
    }
    messageFor(key) {
        return this.localization.get(key);
    }
    onFileSelect(e) {
        const file = e.target.files[0];
        this.fileSelectStart.emit();
        if (file) {
            const reader = new FileReader();
            reader.onload = (e) => {
                const data = e.target.result;
                this.fileSelect.emit(data);
            };
            reader.onerror = (e) => {
                this.fileSelectError.emit(e);
            };
            reader.readAsDataURL(file);
        }
    }
    onZoomLevelChooserValueChange(zoomLevel) {
        this.zoomLevelChange.emit(zoomLevel);
    }
    focus() {
        this.navigationService.focusableTools[this.navigationService.currentFocusIndex].activate();
    }
    valueNormalizer = (text) => text.pipe(map((value) => {
        const parsedValue = parseFloat(value);
        const newValue = Number.isNaN(parsedValue) ? 1 : parsedValue / 100;
        return {
            value: newValue,
            displayValue: `${Math.round(newValue * 100)}%`,
            text: `${Math.round(newValue * 100)}%`
        };
    }));
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarComponent, deps: [{ token: i1.LocalizationService }, { token: ToolbarNavigationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: ToolbarComponent, isStandalone: true, selector: "[kendoPDFViewerToolbar]", inputs: { zoomLevel: "zoomLevel", calculatedComboBoxValue: "calculatedComboBoxValue", skip: "skip", pageSize: "pageSize", total: "total", zoomInDisabled: "zoomInDisabled", zoomOutDisabled: "zoomOutDisabled", disabledTools: "disabledTools", zoomLevelChooserValue: "zoomLevelChooserValue", zoomOptionsData: "zoomOptionsData", pagesContainerId: "pagesContainerId", tools: "tools" }, outputs: { fileSelect: "fileSelect", fileSelectStart: "fileSelectStart", fileSelectError: "fileSelectError", download: "download", selectionEnabled: "selectionEnabled", panningEnabled: "panningEnabled", pageChange: "pageChange", zoomIn: "zoomIn", zoomOut: "zoomOut", zoomLevelChange: "zoomLevelChange", print: "print", search: "search" }, host: { properties: { "class.k-toolbar": "this.toolbarClasses", "class.k-toolbar-md": "this.toolbarClasses", "class.k-toolbar-flat": "this.toolbarClasses" } }, providers: [ToolbarNavigationService], viewQueries: [{ propertyName: "fileSelectEl", first: true, predicate: ["fileSelectEl"], descendants: true }], ngImport: i0, template: `
        <ng-container *ngFor="let tool of tools">
            <ng-container [ngSwitch]="tool">
                <kendo-toolbar-input-wrapper
                    *ngSwitchCase="'pager'"
                    kendoPDFViewerToolbarFocusable
                    [toolbarTool]="pager">
                    <kendo-datapager
                        #pager
                        [attr.aria-controls]="pagesContainerId"
                        [attr.aria-label]="messageFor('page') + ' ' + (skip + 1) + ' ' + messageFor('of') + total"
                        [class.k-disabled]="disabledTools"
                        [navigable]="true"
                        [pageSize]="pageSize"
                        [skip]="skip"
                        [total]="total"
                        [pageSizeValues]="false"
                        [info]="false"
                        [type]="pagerType"
                        (pageChange)="pageChange.emit($event)">
                        <kendo-datapager-messages
                            [firstPage]="messageFor('pagerFirstPage')"
                            [previousPage]="messageFor('pagerPreviousPage')"
                            [nextPage]="messageFor('pagerNextPage')"
                            [lastPage]="messageFor('pagerLastPage')"
                            [inputLabel]="messageFor('pagerInputLabel')"
                            [pageNumberInputTitle]="messageFor('pagerInputTitle')"
                            [of]="messageFor('pagerOf')"
                            [page]="messageFor('pagerPage')"></kendo-datapager-messages>
                    </kendo-datapager>
                </kendo-toolbar-input-wrapper>
                <span
                    *ngSwitchCase="'spacer'"
                    class="k-spacer"></span>
                <kendo-buttongroup
                    *ngSwitchCase="'zoomInOut'"
                    [attr.aria-controls]="pagesContainerId"
                    class="k-button-group-flat k-toolbar-button-group"
                    [navigable]="false">
                    <button
                        type="button"
                        kendoButton
                        fillMode="flat"
                        kendoPDFViewerToolbarFocusable
                        icon="zoom-out"
                        [disabled]="disabledTools || zoomOutDisabled"
                        [svgIcon]="zoomOutIcon"
                        [attr.title]="messageFor('zoomOutTitle')"
                        [attr.aria-label]="messageFor('zoomOutTitle')"
                        (click)="zoomOut.emit()"></button>
                    <button
                        type="button"
                        kendoButton
                        fillMode="flat"
                        kendoPDFViewerToolbarFocusable
                        icon="zoom-in"
                        [disabled]="disabledTools || zoomInDisabled"
                        [svgIcon]="zoomInIcon"
                        [attr.title]="messageFor('zoomInTitle')"
                        [attr.aria-label]="messageFor('zoomInTitle')"
                        (click)="zoomIn.emit()"></button>
                </kendo-buttongroup>
                <kendo-toolbar-input-wrapper
                    *ngSwitchCase="'zoom'"
                    kendoPDFViewerToolbarFocusable
                    [toolbarTool]="combobox">
                    <kendo-combobox
                        #combobox
                        kendoPDFViewerComboBox
                        class="k-toolbar-combobox"
                        fillMode="flat"
                        [attr.aria-controls]="pagesContainerId"
                        [tabindex]="-1"
                        [data]="zoomOptionsData"
                        [disabled]="disabledTools"
                        [placeholder]="messageFor('zoomInputPlaceholder')"
                        textField="displayValue"
                        valueField="id"
                        [value]="zoomLevelChooserValue"
                        [allowCustom]="true"
                        [valueNormalizer]="valueNormalizer"
                        [clearButton]="false"
                        (valueChange)="onZoomLevelChooserValueChange($event)">
                        <ng-template kendoComboBoxItemTemplate let-dataItem>
                            {{ dataItem.type ? messageFor('f' + dataItem.type.slice(1)) : dataItem.text }}
                        </ng-template>
                    </kendo-combobox>
                </kendo-toolbar-input-wrapper>
                <kendo-buttongroup
                    *ngSwitchCase="'selection'"
                    [attr.aria-controls]="pagesContainerId"
                    [navigable]="false"
                    class="k-button-group-flat k-toolbar-button-group"
                    selection="single">
                    <button
                        type="button"
                        kendoButton
                        kendoPDFViewerToolbarFocusable
                        fillMode="flat"
                        icon="pointer"
                        [toggleable]="true"
                        [svgIcon]="pointerIcon"
                        [attr.title]="messageFor('selectionTitle')"
                        [attr.aria-label]="messageFor('selectionTitle')"
                        (click)="selectionEnabled.emit()"></button>
                    <button
                        type="button"
                        kendoButton
                        kendoPDFViewerToolbarFocusable
                        fillMode="flat"
                        icon="hand"
                        [svgIcon]="handIcon"
                        [toggleable]="true"
                        [selected]="true"
                        [attr.title]="messageFor('panningTitle')"
                        [attr.aria-label]="messageFor('panningTitle')"
                        (click)="panningEnabled.emit()"></button>
                </kendo-buttongroup>
                <button
                    *ngSwitchCase="'search'"
                    type="button"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    fillMode="flat"
                    icon="search"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('searchTitle')"
                    [attr.aria-label]="messageFor('searchTitle')"
                    aria-haspopup="dialog"
                    [svgIcon]="searchIcon"
                    (click)="search.emit()"></button>
                <button
                    *ngSwitchCase="'open'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    fillMode="flat"
                    icon="folder-open"
                    [svgIcon]="folderOpenIcon"
                    [attr.title]="messageFor('openTitle')"
                    [attr.aria-label]="messageFor('openTitle')"
                    [attr.aria-controls]="pagesContainerId"
                    (click)="fileSelectEl?.nativeElement.click()">
                </button>
                <button
                    *ngSwitchCase="'download'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    icon="download"
                    [svgIcon]="downloadIcon"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('downloadTitle')"
                    [attr.aria-label]="messageFor('downloadTitle')"
                    (click)="download.emit()"></button>
                <button
                    *ngSwitchCase="'print'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    icon="print"
                    [svgIcon]="printIcon"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('printTitle')"
                    [attr.aria-label]="messageFor('printTitle')"
                    (click)="print.emit()"></button>
            </ng-container>
        </ng-container>
        <input
            #fileSelectEl
            *ngIf="tools?.indexOf('open') > -1;"
            type="file"
            [style.display]="'none'"
            aria-hidden="true"
            accept=".pdf, .PDF"
            (change)="onFileSelect($event)" />
    `, isInline: true, dependencies: [{ kind: "directive", type: NgFor, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "component", type: ToolbarInputWrapperComponent, selector: "kendo-toolbar-input-wrapper", inputs: ["toolbarTool"] }, { kind: "directive", type: ToolbarFocusableDirective, selector: "[kendoPDFViewerToolbarFocusable]" }, { kind: "component", type: PagerComponent, selector: "kendo-datapager, kendo-pager", inputs: ["externalTemplate", "total", "skip", "pageSize", "buttonCount", "info", "type", "pageSizeValues", "previousNext", "navigable", "size", "responsive", "adaptiveMode"], outputs: ["pageChange", "pageSizeChange", "pagerInputVisibilityChange", "pageTextVisibilityChange", "itemsTextVisibilityChange"], exportAs: ["kendoDataPager", "kendoPager"] }, { kind: "component", type: CustomMessagesComponent, selector: "kendo-datapager-messages, kendo-pager-messages" }, { kind: "component", type: ButtonGroupComponent, selector: "kendo-buttongroup", inputs: ["disabled", "selection", "width", "tabIndex", "navigable"], outputs: ["navigate"], exportAs: ["kendoButtonGroup"] }, { kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }, { kind: "component", type: ComboBoxComponent, selector: "kendo-combobox", inputs: ["icon", "svgIcon", "inputAttributes", "showStickyHeader", "focusableId", "allowCustom", "data", "value", "textField", "valueField", "valuePrimitive", "valueNormalizer", "placeholder", "adaptiveMode", "adaptiveTitle", "adaptiveSubtitle", "popupSettings", "listHeight", "loading", "suggest", "clearButton", "disabled", "itemDisabled", "readonly", "tabindex", "tabIndex", "filterable", "virtual", "size", "rounded", "fillMode"], outputs: ["valueChange", "selectionChange", "filterChange", "open", "opened", "close", "closed", "focus", "blur", "inputFocus", "inputBlur", "escape"], exportAs: ["kendoComboBox"] }, { kind: "directive", type: ToolbarComboBoxDirective, selector: "[kendoPDFViewerComboBox]" }, { kind: "directive", type: ItemTemplateDirective, selector: "[kendoDropDownListItemTemplate],[kendoComboBoxItemTemplate],[kendoAutoCompleteItemTemplate],[kendoMultiSelectItemTemplate]" }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: ToolbarComponent, decorators: [{
            type: Component,
            args: [{
                    selector: '[kendoPDFViewerToolbar]',
                    providers: [ToolbarNavigationService],
                    template: `
        <ng-container *ngFor="let tool of tools">
            <ng-container [ngSwitch]="tool">
                <kendo-toolbar-input-wrapper
                    *ngSwitchCase="'pager'"
                    kendoPDFViewerToolbarFocusable
                    [toolbarTool]="pager">
                    <kendo-datapager
                        #pager
                        [attr.aria-controls]="pagesContainerId"
                        [attr.aria-label]="messageFor('page') + ' ' + (skip + 1) + ' ' + messageFor('of') + total"
                        [class.k-disabled]="disabledTools"
                        [navigable]="true"
                        [pageSize]="pageSize"
                        [skip]="skip"
                        [total]="total"
                        [pageSizeValues]="false"
                        [info]="false"
                        [type]="pagerType"
                        (pageChange)="pageChange.emit($event)">
                        <kendo-datapager-messages
                            [firstPage]="messageFor('pagerFirstPage')"
                            [previousPage]="messageFor('pagerPreviousPage')"
                            [nextPage]="messageFor('pagerNextPage')"
                            [lastPage]="messageFor('pagerLastPage')"
                            [inputLabel]="messageFor('pagerInputLabel')"
                            [pageNumberInputTitle]="messageFor('pagerInputTitle')"
                            [of]="messageFor('pagerOf')"
                            [page]="messageFor('pagerPage')"></kendo-datapager-messages>
                    </kendo-datapager>
                </kendo-toolbar-input-wrapper>
                <span
                    *ngSwitchCase="'spacer'"
                    class="k-spacer"></span>
                <kendo-buttongroup
                    *ngSwitchCase="'zoomInOut'"
                    [attr.aria-controls]="pagesContainerId"
                    class="k-button-group-flat k-toolbar-button-group"
                    [navigable]="false">
                    <button
                        type="button"
                        kendoButton
                        fillMode="flat"
                        kendoPDFViewerToolbarFocusable
                        icon="zoom-out"
                        [disabled]="disabledTools || zoomOutDisabled"
                        [svgIcon]="zoomOutIcon"
                        [attr.title]="messageFor('zoomOutTitle')"
                        [attr.aria-label]="messageFor('zoomOutTitle')"
                        (click)="zoomOut.emit()"></button>
                    <button
                        type="button"
                        kendoButton
                        fillMode="flat"
                        kendoPDFViewerToolbarFocusable
                        icon="zoom-in"
                        [disabled]="disabledTools || zoomInDisabled"
                        [svgIcon]="zoomInIcon"
                        [attr.title]="messageFor('zoomInTitle')"
                        [attr.aria-label]="messageFor('zoomInTitle')"
                        (click)="zoomIn.emit()"></button>
                </kendo-buttongroup>
                <kendo-toolbar-input-wrapper
                    *ngSwitchCase="'zoom'"
                    kendoPDFViewerToolbarFocusable
                    [toolbarTool]="combobox">
                    <kendo-combobox
                        #combobox
                        kendoPDFViewerComboBox
                        class="k-toolbar-combobox"
                        fillMode="flat"
                        [attr.aria-controls]="pagesContainerId"
                        [tabindex]="-1"
                        [data]="zoomOptionsData"
                        [disabled]="disabledTools"
                        [placeholder]="messageFor('zoomInputPlaceholder')"
                        textField="displayValue"
                        valueField="id"
                        [value]="zoomLevelChooserValue"
                        [allowCustom]="true"
                        [valueNormalizer]="valueNormalizer"
                        [clearButton]="false"
                        (valueChange)="onZoomLevelChooserValueChange($event)">
                        <ng-template kendoComboBoxItemTemplate let-dataItem>
                            {{ dataItem.type ? messageFor('f' + dataItem.type.slice(1)) : dataItem.text }}
                        </ng-template>
                    </kendo-combobox>
                </kendo-toolbar-input-wrapper>
                <kendo-buttongroup
                    *ngSwitchCase="'selection'"
                    [attr.aria-controls]="pagesContainerId"
                    [navigable]="false"
                    class="k-button-group-flat k-toolbar-button-group"
                    selection="single">
                    <button
                        type="button"
                        kendoButton
                        kendoPDFViewerToolbarFocusable
                        fillMode="flat"
                        icon="pointer"
                        [toggleable]="true"
                        [svgIcon]="pointerIcon"
                        [attr.title]="messageFor('selectionTitle')"
                        [attr.aria-label]="messageFor('selectionTitle')"
                        (click)="selectionEnabled.emit()"></button>
                    <button
                        type="button"
                        kendoButton
                        kendoPDFViewerToolbarFocusable
                        fillMode="flat"
                        icon="hand"
                        [svgIcon]="handIcon"
                        [toggleable]="true"
                        [selected]="true"
                        [attr.title]="messageFor('panningTitle')"
                        [attr.aria-label]="messageFor('panningTitle')"
                        (click)="panningEnabled.emit()"></button>
                </kendo-buttongroup>
                <button
                    *ngSwitchCase="'search'"
                    type="button"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    fillMode="flat"
                    icon="search"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('searchTitle')"
                    [attr.aria-label]="messageFor('searchTitle')"
                    aria-haspopup="dialog"
                    [svgIcon]="searchIcon"
                    (click)="search.emit()"></button>
                <button
                    *ngSwitchCase="'open'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    fillMode="flat"
                    icon="folder-open"
                    [svgIcon]="folderOpenIcon"
                    [attr.title]="messageFor('openTitle')"
                    [attr.aria-label]="messageFor('openTitle')"
                    [attr.aria-controls]="pagesContainerId"
                    (click)="fileSelectEl?.nativeElement.click()">
                </button>
                <button
                    *ngSwitchCase="'download'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    icon="download"
                    [svgIcon]="downloadIcon"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('downloadTitle')"
                    [attr.aria-label]="messageFor('downloadTitle')"
                    (click)="download.emit()"></button>
                <button
                    *ngSwitchCase="'print'"
                    type="button"
                    fillMode="flat"
                    kendoPDFViewerToolbarFocusable
                    kendoButton
                    class="k-toolbar-button"
                    icon="print"
                    [svgIcon]="printIcon"
                    [disabled]="disabledTools"
                    [attr.title]="messageFor('printTitle')"
                    [attr.aria-label]="messageFor('printTitle')"
                    (click)="print.emit()"></button>
            </ng-container>
        </ng-container>
        <input
            #fileSelectEl
            *ngIf="tools?.indexOf('open') > -1;"
            type="file"
            [style.display]="'none'"
            aria-hidden="true"
            accept=".pdf, .PDF"
            (change)="onFileSelect($event)" />
    `,
                    standalone: true,
                    imports: [NgFor, NgSwitch, NgSwitchCase, ToolbarInputWrapperComponent, ToolbarFocusableDirective, PagerComponent, CustomMessagesComponent, ButtonGroupComponent, ButtonComponent, ComboBoxComponent, ToolbarComboBoxDirective, ItemTemplateDirective, NgIf]
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }, { type: ToolbarNavigationService }]; }, propDecorators: { toolbarClasses: [{
                type: HostBinding,
                args: ['class.k-toolbar']
            }, {
                type: HostBinding,
                args: ['class.k-toolbar-md']
            }, {
                type: HostBinding,
                args: ['class.k-toolbar-flat']
            }], fileSelectEl: [{
                type: ViewChild,
                args: ['fileSelectEl']
            }], zoomLevel: [{
                type: Input
            }], calculatedComboBoxValue: [{
                type: Input
            }], skip: [{
                type: Input
            }], pageSize: [{
                type: Input
            }], total: [{
                type: Input
            }], zoomInDisabled: [{
                type: Input
            }], zoomOutDisabled: [{
                type: Input
            }], disabledTools: [{
                type: Input
            }], zoomLevelChooserValue: [{
                type: Input
            }], zoomOptionsData: [{
                type: Input
            }], pagesContainerId: [{
                type: Input
            }], tools: [{
                type: Input
            }], fileSelect: [{
                type: Output
            }], fileSelectStart: [{
                type: Output
            }], fileSelectError: [{
                type: Output
            }], download: [{
                type: Output
            }], selectionEnabled: [{
                type: Output
            }], panningEnabled: [{
                type: Output
            }], pageChange: [{
                type: Output
            }], zoomIn: [{
                type: Output
            }], zoomOut: [{
                type: Output
            }], zoomLevelChange: [{
                type: Output
            }], print: [{
                type: Output
            }], search: [{
                type: Output
            }] } });

/**
 * @hidden
 */
class PDFViewerSearchComponent {
    localization;
    textbox;
    closeButton;
    ariaRole = 'dialog';
    onEscape() {
        this.close.emit();
    }
    matches;
    currentMatch;
    searchChange = new EventEmitter();
    prevMatch = new EventEmitter();
    nextMatch = new EventEmitter();
    close = new EventEmitter();
    convertLowercaseIcon = convertLowercaseIcon;
    arrowUpIcon = arrowUpIcon;
    arrowDownIcon = arrowDownIcon;
    xIcon = xIcon;
    value = null;
    matchCase = false;
    constructor(localization) {
        this.localization = localization;
    }
    ngAfterViewInit() {
        this.textbox.focus();
    }
    messageFor(key) {
        return this.localization.get(key);
    }
    onShiftTab(e) {
        if (e.target.matches('.k-input-inner')) {
            e.preventDefault();
            this.closeButton.nativeElement.focus();
        }
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerSearchComponent, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: PDFViewerSearchComponent, isStandalone: true, selector: "[kendoPDFViewerSearch]", inputs: { matches: "matches", currentMatch: "currentMatch" }, outputs: { searchChange: "searchChange", prevMatch: "prevMatch", nextMatch: "nextMatch", close: "close" }, host: { listeners: { "keydown.escape": "onEscape()" }, properties: { "attr.role": "this.ariaRole" } }, viewQueries: [{ propertyName: "textbox", first: true, predicate: ["textbox"], descendants: true }, { propertyName: "closeButton", first: true, predicate: ["closeButton"], descendants: true, read: ElementRef }], ngImport: i0, template: `
        <kendo-textbox
            #textbox
            [placeholder]="messageFor('searchInputPlaceholder')"
            [value]="value"
            (valueChange)="value = $event; searchChange.emit({text: $event, matchCase})"
            (keydown.shift.tab)="onShiftTab($event)">
            <ng-template kendoTextBoxSuffixTemplate>
                <button
                    type="button"
                    kendoButton
                    [attr.title]="messageFor('searchMatchCaseTitle')"
                    fillMode="flat"
                    [togglable]="true"
                    (click)="matchCase = !matchCase; searchChange.emit({text: value, matchCase})"
                    icon="convert-lowercase"
                    [svgIcon]="convertLowercaseIcon"></button>
            </ng-template>
        </kendo-textbox>
        <span class="k-search-matches">
            <span>{{currentMatch}}</span> {{messageFor('searchMatchesOf')}} <span>{{matches}}</span>
        </span>
        <button
            type="button"
            kendoButton
            [attr.title]="messageFor('searchPreviousMatchTitle')"
            fillMode="flat"
            [disabled]="matches === 0"
            (click)="prevMatch.emit()"
            icon='arrow-up'
            [svgIcon]="arrowUpIcon"></button>
        <button
            type="button"
            kendoButton
            [attr.title]="messageFor('searchNextMatchTitle')"
            fillMode="flat"
            [disabled]="matches === 0"
            (click)="nextMatch.emit()"
            icon='arrow-down'
            [svgIcon]="arrowDownIcon"></button>
        <button
            type="button"
            #closeButton
            kendoButton
            [attr.title]="messageFor('searchCloseTitle')"
            fillMode="flat"
            (click)="close.emit()"
            (keydown.tab)="$event.preventDefault(); textbox.focus();"
            icon='x'
            [svgIcon]="xIcon"></button>
    `, isInline: true, dependencies: [{ kind: "component", type: TextBoxComponent, selector: "kendo-textbox", inputs: ["focusableId", "title", "type", "disabled", "readonly", "tabindex", "value", "selectOnFocus", "showSuccessIcon", "showErrorIcon", "clearButton", "successIcon", "successSvgIcon", "errorIcon", "errorSvgIcon", "clearButtonIcon", "clearButtonSvgIcon", "size", "rounded", "fillMode", "tabIndex", "placeholder", "maxlength", "inputAttributes"], outputs: ["valueChange", "inputFocus", "inputBlur", "focus", "blur"], exportAs: ["kendoTextBox"] }, { kind: "directive", type: TextBoxSuffixTemplateDirective, selector: "[kendoTextBoxSuffixTemplate]", inputs: ["showSeparator"] }, { kind: "component", type: ButtonComponent, selector: "button[kendoButton]", inputs: ["arrowIcon", "toggleable", "togglable", "selected", "tabIndex", "imageUrl", "iconClass", "icon", "disabled", "size", "rounded", "fillMode", "themeColor", "svgIcon", "primary", "look"], outputs: ["selectedChange", "click"], exportAs: ["kendoButton"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerSearchComponent, decorators: [{
            type: Component,
            args: [{
                    selector: '[kendoPDFViewerSearch]',
                    template: `
        <kendo-textbox
            #textbox
            [placeholder]="messageFor('searchInputPlaceholder')"
            [value]="value"
            (valueChange)="value = $event; searchChange.emit({text: $event, matchCase})"
            (keydown.shift.tab)="onShiftTab($event)">
            <ng-template kendoTextBoxSuffixTemplate>
                <button
                    type="button"
                    kendoButton
                    [attr.title]="messageFor('searchMatchCaseTitle')"
                    fillMode="flat"
                    [togglable]="true"
                    (click)="matchCase = !matchCase; searchChange.emit({text: value, matchCase})"
                    icon="convert-lowercase"
                    [svgIcon]="convertLowercaseIcon"></button>
            </ng-template>
        </kendo-textbox>
        <span class="k-search-matches">
            <span>{{currentMatch}}</span> {{messageFor('searchMatchesOf')}} <span>{{matches}}</span>
        </span>
        <button
            type="button"
            kendoButton
            [attr.title]="messageFor('searchPreviousMatchTitle')"
            fillMode="flat"
            [disabled]="matches === 0"
            (click)="prevMatch.emit()"
            icon='arrow-up'
            [svgIcon]="arrowUpIcon"></button>
        <button
            type="button"
            kendoButton
            [attr.title]="messageFor('searchNextMatchTitle')"
            fillMode="flat"
            [disabled]="matches === 0"
            (click)="nextMatch.emit()"
            icon='arrow-down'
            [svgIcon]="arrowDownIcon"></button>
        <button
            type="button"
            #closeButton
            kendoButton
            [attr.title]="messageFor('searchCloseTitle')"
            fillMode="flat"
            (click)="close.emit()"
            (keydown.tab)="$event.preventDefault(); textbox.focus();"
            icon='x'
            [svgIcon]="xIcon"></button>
    `,
                    standalone: true,
                    imports: [TextBoxComponent, TextBoxSuffixTemplateDirective, ButtonComponent]
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; }, propDecorators: { textbox: [{
                type: ViewChild,
                args: ['textbox']
            }], closeButton: [{
                type: ViewChild,
                args: ['closeButton', { read: ElementRef }]
            }], ariaRole: [{
                type: HostBinding,
                args: ['attr.role']
            }], onEscape: [{
                type: HostListener,
                args: ['keydown.escape']
            }], matches: [{
                type: Input
            }], currentMatch: [{
                type: Input
            }], searchChange: [{
                type: Output
            }], prevMatch: [{
                type: Output
            }], nextMatch: [{
                type: Output
            }], close: [{
                type: Output
            }] } });

/**
 * @hidden
 */
class LoaderComponent {
    settings;
    loaderContainerClass = true;
    loaderContainerSizingClass = true;
    loaderPositionClass = true;
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LoaderComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: LoaderComponent, isStandalone: true, selector: "[kendoPDFViewerLoader]", inputs: { settings: "settings" }, host: { properties: { "class.k-loader-container": "this.loaderContainerClass", "class.k-loader-container-md": "this.loaderContainerSizingClass", "class.k-loader-top": "this.loaderPositionClass" } }, ngImport: i0, template: `
        <div class="k-loader-container-overlay k-overlay-light"></div>
        <div class="k-loader-container-inner">
            <kendo-loader
                [size]="settings?.size"
                [type]="settings?.type"
                [themeColor]="settings?.themeColor"></kendo-loader>
        </div>
    `, isInline: true, dependencies: [{ kind: "component", type: LoaderComponent$1, selector: "kendo-loader", inputs: ["type", "themeColor", "size"] }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LoaderComponent, decorators: [{
            type: Component,
            args: [{
                    selector: '[kendoPDFViewerLoader]',
                    template: `
        <div class="k-loader-container-overlay k-overlay-light"></div>
        <div class="k-loader-container-inner">
            <kendo-loader
                [size]="settings?.size"
                [type]="settings?.type"
                [themeColor]="settings?.themeColor"></kendo-loader>
        </div>
    `,
                    standalone: true,
                    imports: [LoaderComponent$1]
                }]
        }], propDecorators: { settings: [{
                type: Input
            }], loaderContainerClass: [{
                type: HostBinding,
                args: ['class.k-loader-container']
            }], loaderContainerSizingClass: [{
                type: HostBinding,
                args: ['class.k-loader-container-md']
            }], loaderPositionClass: [{
                type: HostBinding,
                args: ['class.k-loader-top']
            }] } });

/**
 * @hidden
 */
class LocalizedPDFViewerMessagesDirective extends Messages {
    service;
    constructor(service) {
        super();
        this.service = service;
    }
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LocalizedPDFViewerMessagesDirective, deps: [{ token: i1.LocalizationService }], target: i0.ɵɵFactoryTarget.Directive });
    static ɵdir = i0.ɵɵngDeclareDirective({ minVersion: "14.0.0", version: "16.2.12", type: LocalizedPDFViewerMessagesDirective, isStandalone: true, selector: "[kendoPDFViewerLocalizedMessages]", providers: [
            {
                provide: Messages,
                useExisting: forwardRef(() => LocalizedPDFViewerMessagesDirective)
            }
        ], usesInheritance: true, ngImport: i0 });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: LocalizedPDFViewerMessagesDirective, decorators: [{
            type: Directive,
            args: [{
                    providers: [
                        {
                            provide: Messages,
                            useExisting: forwardRef(() => LocalizedPDFViewerMessagesDirective)
                        }
                    ],
                    selector: '[kendoPDFViewerLocalizedMessages]',
                    standalone: true
                }]
        }], ctorParameters: function () { return [{ type: i1.LocalizationService }]; } });

let counter = 0;
/**
 * Represents the [Kendo UI PDFViewer component for Angular](slug:overview_pdfviewer).
 *
 * @example
 * ```html
 * <kendo-pdfviewer
 *   [url]="pdfUrl"
 *   [zoom]="1.25"
 *   [tools]="['pager', 'zoomInOut', 'zoom', 'download', 'print']">
 * </kendo-pdfviewer>
 * ```
 *
 * @remarks
 * Supported children components are: {@link PDFViewerCustomMessagesComponent}
 */
class PDFViewerComponent {
    ngZone;
    renderer;
    localizationService;
    cdr;
    host;
    hostClass = true;
    direction;
    /**
     * Represents the tools collection rendered in the toolbar.
     * @default ['pager', 'spacer', 'zoomInOut', 'zoom', 'selection', 'spacer', 'search', 'open', 'download', 'print' ]
     */
    tools = [
        'pager',
        'spacer',
        'zoomInOut',
        'zoom',
        'selection',
        'spacer',
        'search',
        'open',
        'download',
        'print'
    ];
    /**
     * The configuration of the internal Loader component.
     * @default { size: 'large', type: 'pulsing', themeColor: 'primary' }
     */
    loaderSettings = {
        size: 'large',
        type: 'pulsing',
        themeColor: 'primary'
    };
    /**
     * The name of the file that will be saved when the end user clicks the Download tool.
     * @default 'Download'
     */
    saveFileName = 'Download';
    /**
     * Represents the options for saving the file when the end user clicks the Download tool.
     * @default {}
     */
    saveOptions = {};
    /**
     * Represents the url of the PDF file.
     */
    url;
    /**
     * Represents the data of the PDF file in [Base64 format](https://developer.mozilla.org/en-US/docs/Glossary/Base64).
     */
    data;
    /**
     * Represents the raw [binary data buffer](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/ArrayBuffer) of the PDF file.
     */
    arrayBuffer;
    /**
     * Represents the data of the PDF file in [`TypedArray`](https://developer.mozilla.org/en-US/docs/Web/JavaScript/Reference/Global_Objects/TypedArray) format.
     */
    typedArray;
    /**
     * Sets the initial zoom level of the PDF document
     * ([see example](slug:tools_pdfviewer#zooming-tools)).
     *
     * @default 1.25
     */
    set zoom(value) {
        if (typeof value === 'number') {
            this._zoom = value;
            this._fitType = null;
            this.setZoomLevel(value);
        }
        else {
            this._zoom = INITIAL_ZOOM_LEVEL;
            this._fitType = zoomToFitOptions[value];
        }
        this._zoomToFit = typeof value !== 'number';
    }
    get zoom() {
        return this._zoom;
    }
    /**
     * Represents the step the zoom level will be changed with when using the **ZoomIn** and **ZoomOut** tools.
     * @default 0.25
     */
    zoomRate = 0.25;
    /**
     * Represents minimum allowed zoom value.
     * @default 0.5
     */
    minZoom = 0.5;
    /**
     * Represents maximum allowed zoom value.
     * @default 4
     */
    maxZoom = 4;
    /**
     * Sets whether the component loads all PDF document pages at once or loads new pages on demand when needed.
     *
     * @default false
     */
    loadOnDemand = false;
    /**
     * Sets the number of pages to load on demand when the `loadOnDemand` property is `true`.
     *
     * @default 1
     */
    loadOnDemandPageSize = 1;
    /**
     * Fires when the component loads a PDF document successfully.
     */
    load = new EventEmitter();
    /**
     * Fires when an error occurs while loading or downloading the PDF document.
     */
    error = new EventEmitter();
    /**
     * Fires when the user clicks the **Download** tool of the loaded PDF document.
     */
    download = new EventEmitter();
    /**
     * Fires when the user changes the page of the loaded PDF document.
     */
    pageChange = new EventEmitter();
    /**
     * Fires when the user changes the zoom level of the loaded PDF document.
     */
    zoomLevelChange = new EventEmitter();
    pagesContainer;
    /**
     * Returns the current page number of the loaded PDF document.
     */
    get currentPage() {
        const isDocumentLoaded = this.pagesContainer && this.pdfContext?.pdfDoc;
        return isDocumentLoaded ? this.skip + 1 : null;
    }
    set pdfContext(doc) {
        this._pdfContext = doc;
    }
    /**
     * Exposes the loaded `PDF.js` document, its pages, and their DOM element wrapper.
     */
    get pdfContext() {
        return this._pdfContext;
    }
    /**
     * @hidden
     */
    get activePageId() {
        if (!this.pdfContext?.pdfPages.length) {
            return;
        }
        return this.pagesContainer.nativeElement.querySelectorAll('.k-page')[this.skip]?.getAttribute('id');
    }
    /**
     * @hidden
     */
    get pagesContainerId() {
        if (!this.pdfContext?.pdfPages.length) {
            return;
        }
        return `k-pdfviewer-${counter}-pages-container`;
    }
    loading = false;
    searchActive = false;
    matchCase = false;
    currentMatches = [];
    currentMatch;
    /**
     * @hidden
     */
    set enabledSelection(value) {
        if (this.pdfViewerWidget) {
            value ? this.pdfViewerWidget.documentScroller.disablePanEventsTracking() : this.pdfViewerWidget.documentScroller.enablePanEventsTracking();
        }
        this._enabledSelection = value;
    }
    /**
     * @hidden
     */
    get enabledSelection() {
        return this._enabledSelection;
    }
    /**
     * @hidden
     */
    showLicenseWatermark = false;
    skip = 0;
    zoomOptionsData = zoomOptionsData;
    zoomLevel = this.zoomOptionsData[5];
    _pdfContext = null;
    _enabledSelection = false;
    _zoom = INITIAL_ZOOM_LEVEL;
    _fitType;
    _zoomToFit = false;
    subs = new Subscription();
    emitLoad = true;
    constructor(ngZone, renderer, localizationService, cdr, host) {
        this.ngZone = ngZone;
        this.renderer = renderer;
        this.localizationService = localizationService;
        this.cdr = cdr;
        this.host = host;
        const isValid = validatePackage(packageMetadata);
        this.showLicenseWatermark = shouldShowValidationUI(isValid);
        this.direction = localizationService.rtl ? 'rtl' : 'ltr';
        counter++;
    }
    ngOnInit() {
        this.subs.add(this.localizationService.changes.subscribe(({ rtl }) => this.direction = rtl ? 'rtl' : 'ltr'));
    }
    ngOnDestroy() {
        this.subs.unsubscribe();
        this.pdfViewerWidget?.destroy();
        this.pdfContext = null;
    }
    ngOnChanges(changes) {
        const newBase64Data = changes['data'] && this.data;
        const newUrl = changes['url'] && this.url;
        const newArrayBuffer = changes['arrayBuffer'] && this.arrayBuffer;
        const newTypedArray = changes['typedArray'] && this.typedArray;
        this.verifySettings(changes);
        const dataOrTypedArray = newBase64Data ? 'data' : 'typedArray';
        const bufferOrDataOrTypedArray = newArrayBuffer ? 'arrayBuffer' : dataOrTypedArray;
        const source = newUrl ? 'url' : bufferOrDataOrTypedArray;
        if (newUrl || newArrayBuffer || newBase64Data || newTypedArray) {
            this.loadPdf(source, this[source]);
        }
    }
    /**
     * Scrolls the PDFViewer document to the specified page number, treating 0 as the first page
     * ([see example](slug:tools_pdfviewer#programmatically-scrolling-the-pdfviewer)).
     */
    scrollToPage(page) {
        this.pdfViewerWidget?.scrollToPage({ pageNumber: page });
    }
    /**
     * @hidden
     */
    onFileSelect(e) {
        this.loadPdf('data', e);
    }
    /**
     * @hidden
     */
    onFileSelectError(e) {
        this.zoneAwareEmitter('error', { error: e, context: this.pdfContext });
    }
    /**
     * @hidden
     */
    onPageChange(e) {
        this.ngZone.runOutsideAngular(() => this.scrollToPage(e.skip + 1));
    }
    /**
     * @hidden
     */
    onDownload() {
        this.ngZone.runOutsideAngular(() => this.pdfContext.pdfDoc.getData()
            .then((data) => new Blob([data], { type: 'application/pdf' }))
            .then((blob) => {
            const downloadEvent = new PDFViewerDownloadEvent(blob, this.saveFileName, this.saveOptions, this.pdfContext);
            this.zoneAwareEmitter('download', downloadEvent);
            if (!downloadEvent.isDefaultPrevented()) {
                saveAs(blob, this.saveFileName, this.saveOptions);
            }
        })
            .catch((reason) => {
            this.zoneAwareEmitter('error', { error: reason, context: this.pdfContext });
        }));
    }
    /**
     * @hidden
     */
    stopPropagation = (e) => {
        if (e.ctrlKey || e.metaKey) {
            e.preventDefault();
        }
    };
    /**
     * @hidden
     */
    onZoomIn() {
        const newZoom = Math.min(this.zoom + this.zoomRate, this.maxZoom);
        if (newZoom !== this.zoom && this.pdfContext.pdfDoc) {
            this.zoneAwareEmitter('zoomLevelChange', {
                previousZoomLevel: this.zoom,
                currentZoomLevel: newZoom
            });
            this.zoom = this.pdfContext.zoom = newZoom;
        }
    }
    /**
     * @hidden
     */
    onZoomOut() {
        const newZoom = Math.max(this.zoom - this.zoomRate, this.minZoom);
        if (newZoom !== this.zoom && this.pdfContext.pdfDoc) {
            this.zoneAwareEmitter('zoomLevelChange', {
                previousZoomLevel: this.zoom,
                currentZoomLevel: newZoom
            });
            this.zoom = this.pdfContext.zoom = newZoom;
        }
    }
    /**
     * @hidden
     */
    onZoomLevelChange(zoomLevel, emit = true) {
        if (!zoomLevel) {
            zoomLevel = {
                value: 1,
                displayValue: '100%',
                text: '100%'
            };
        }
        let newZoom = zoomLevel.type ? this.pdfViewerWidget?.calculateZoomLevel({
            zoomLevel: zoomLevel.value,
            zoomLevelType: zoomLevel.type,
            currentZoom: this.zoom
        }) : Math.min(Math.max(zoomLevel.value, this.minZoom), this.maxZoom);
        newZoom = Math.round((newZoom + Number.EPSILON) * 100) / 100;
        const sameZoom = this.zoom === newZoom;
        if (!sameZoom) {
            emit && this.zoneAwareEmitter('zoomLevelChange', {
                previousZoomLevel: this.zoom,
                currentZoomLevel: newZoom
            });
            this.zoom = this.pdfContext.zoom = newZoom;
        }
        else {
            this.setZoomLevel(newZoom, zoomLevel.type);
        }
    }
    /**
     * @hidden
     */
    onSearch() {
        this.searchActive = true;
    }
    /**
     * @hidden
     */
    onPrint() {
        this.loading = true;
        this.pdfViewerWidget?.printFile();
    }
    /**
     * @hidden
     */
    onSearchChange(e) {
        this.currentMatches = this.pdfViewerWidget.searchService.search({ ...e });
        this.currentMatch = this.currentMatches.length ? 1 : 0;
    }
    /**
     * @hidden
     */
    closeSearch(toolbar) {
        this.searchActive = false;
        this.pdfViewerWidget.searchService.destroy();
        this.currentMatches = [];
        this.currentMatch = null;
        toolbar.focus();
    }
    /**
     * @hidden
     */
    onNextMatch() {
        this.pdfViewerWidget?.goToNextSearchMatch();
        this.currentMatch = this.currentMatch + 1 > this.currentMatches.length ? 1 : this.currentMatch + 1;
    }
    /**
     * @hidden
     */
    onPreviousMatch() {
        this.pdfViewerWidget?.goToPreviousSearchMatch();
        this.currentMatch = this.currentMatch - 1 < 1 ? this.currentMatches.length : this.currentMatch - 1;
    }
    pdfViewerWidget;
    loadPdf(dataType, data) {
        this.pdfViewerWidget?.destroy();
        this.loading = true;
        this.emitLoad = true;
        this.ngZone.runOutsideAngular(() => {
            // try to destroy if new dynamic data source
            this.pagesContainer && removeChildren(this.pagesContainer.nativeElement);
            const file = dataType === 'url' || dataType === 'data' ? { [dataType]: data } : { data };
            this.pdfViewerWidget = new PdfViewer(this.host.nativeElement, {
                loadOnDemand: this.loadOnDemand,
                loadOnDemandPageSize: this.loadOnDemandPageSize,
                zoomLevel: this.zoom,
                scaleFactor: 1,
                fileDescriptor: file,
                events: {
                    pagesLoad: this.loadHandler,
                    zoomStart: () => {
                        this.skip = this.pdfViewerWidget.getCurrentPageIndex();
                    },
                    zoomEnd: this.zoomEndHandler,
                    printEnd: () => {
                        this.loading = false;
                    },
                    scroll: this.scrollHandler,
                    error: this.errorHandler
                }
            });
        });
    }
    assignPageIds() {
        this.pagesContainer.nativeElement.querySelectorAll('.k-page').forEach((pageElement, index) => {
            const id = `k-pdfviewer-${counter}-page-${index + 1}`;
            this.renderer.setAttribute(pageElement, 'id', id);
        });
    }
    setZoomLevel(zoom, type) {
        const option = this.zoomOptionsData.find(item => (!item.type && item.value === zoom) || (item.type && item.type === type));
        this.zoomLevel = structuredClone(option) ?? {
            value: zoom,
            displayValue: `${Math.round(zoom * 100)}%`,
            text: `${Math.round(zoom * 100)}%`
        };
        this.pdfViewerWidget?.zoom({ zoomLevel: zoom, zoomLevelType: type });
    }
    verifySettings(changes) {
        const sourceTypes = ['url', 'arrayBuffer', 'data', 'typedArray'];
        const setTypes = sourceTypes.map(item => this.isSet(changes, item)).filter(item => item);
        if (isDevMode() && setTypes.length > 1) {
            console.warn(`
                Setting more than one source of data simultaneously is not supported.
                Only one of 'url', 'arrayBuffer', 'data', or 'typedArray' can be set.
            `);
        }
    }
    isSet(changes, source) {
        return this[source] || changes[source]?.currentValue;
    }
    scrollHandler = (e) => {
        const currentPage = this.currentPage;
        this.skip = e.pageNumber - 1;
        this.cdr.markForCheck();
        if (e.isPageChanged) {
            this.zoneAwareEmitter('pageChange', {
                previousPage: currentPage,
                currentPage: e.pageNumber
            });
        }
    };
    loadHandler = (e) => {
        if (!this.pdfContext) {
            this.pdfViewerWidget.documentScroller.enablePanEventsTracking();
        }
        if (!this._zoomToFit) {
            this.pdfContext = { ...e, element: this.pagesContainer.nativeElement, zoom: e.sender.state.zoomLevel };
            if (this.emitLoad) {
                this.zoneAwareEmitter('load', { context: this.pdfContext });
                this.emitLoad = false;
            }
        }
        else {
            const zoomLevelOption = this.zoomOptionsData.find(item => item.type === this._fitType);
            this.pdfContext = { ...e, element: this.pagesContainer.nativeElement };
            this.onZoomLevelChange(zoomLevelOption, false);
        }
        this.cdr.markForCheck();
        this.assignPageIds();
        this.ngZone.run(() => this.loading = false);
    };
    zoomEndHandler = (e) => {
        const zoom = Math.round(Math.min(Math.max(e.zoomLevel, this.minZoom), this.maxZoom) * 100) / 100;
        this.zoneAwareEmitter('zoomLevelChange', {
            currentZoomLevel: zoom,
            previousZoomLevel: this.zoom
        });
        this.zoom = zoom;
    };
    errorHandler = (e) => {
        this.ngZone.run(() => this.loading = false);
        this.pdfContext = null;
        this.zoneAwareEmitter('error', { error: e, context: this.pdfContext });
    };
    zoneAwareEmitter = (eventName, eventData) => {
        if (hasObservers(this[eventName])) {
            this.ngZone.run(() => this[eventName].emit(eventData));
        }
    };
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerComponent, deps: [{ token: i0.NgZone }, { token: i0.Renderer2 }, { token: i1.LocalizationService }, { token: i0.ChangeDetectorRef }, { token: i0.ElementRef }], target: i0.ɵɵFactoryTarget.Component });
    static ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "16.2.12", type: PDFViewerComponent, isStandalone: true, selector: "kendo-pdfviewer", inputs: { tools: "tools", loaderSettings: "loaderSettings", saveFileName: "saveFileName", saveOptions: "saveOptions", url: "url", data: "data", arrayBuffer: "arrayBuffer", typedArray: "typedArray", zoom: "zoom", zoomRate: "zoomRate", minZoom: "minZoom", maxZoom: "maxZoom", loadOnDemand: "loadOnDemand", loadOnDemandPageSize: "loadOnDemandPageSize" }, outputs: { load: "load", error: "error", download: "download", pageChange: "pageChange", zoomLevelChange: "zoomLevelChange" }, host: { properties: { "class.k-pdf-viewer": "this.hostClass", "attr.dir": "this.direction" } }, providers: [
            LocalizationService,
            {
                provide: L10N_PREFIX,
                useValue: 'kendo.pdfviewer'
            }
        ], viewQueries: [{ propertyName: "pagesContainer", first: true, predicate: ["pagesContainer"], descendants: true }], exportAs: ["kendo-pdfviewer"], usesOnChanges: true, ngImport: i0, template: `
        <ng-container kendoPDFViewerLocalizedMessages
            i18n-pagerFirstPage="kendo.pdfviewer.pagerFirstPage|The label for the first page button in the Pager"
            pagerFirstPage="Go to the first page"

            i18n-pagerPreviousPage="kendo.pdfviewer.pagerPreviousPage|The label for the previous page button in the Pager"
            pagerPreviousPage="Go to the previous page"

            i18n-pagerNextPage="kendo.pdfviewer.pagerNextPage|The label for the next page button in the Pager"
            pagerNextPage="Go to the next page"

            i18n-pagerLastPage="kendo.pdfviewer.pagerLastPage|The label for the last page button in the Pager"
            pagerLastPage="Go to the last page"

            i18n-pagerPage="kendo.pdfviewer.pagerPage|The text before the current page number in the Pager"
            pagerPage="Page"

            i18n-pagerOf="kendo.pdfviewer.pagerOf|The text before the total pages number in the Pager"
            pagerOf="of"

            i18n-pagerInputTitle="kendo.pdfviewer.pagerInputTitle|The label of the pager input element"
            pagerInputTitle="Page Number"

            i18n-pagerInputLabel="kendo.pdfviewer.pagerInputLabel|The text of the aria-label attribute applied to the input element for entering the page number."
            pagerInputLabel="Type a page number"
            
            i18n-zoomInTitle="kendo.pdfviewer.zoomInTitle|The ZoomIn tool title and label."
            zoomInTitle="Zoom in"
            
            i18n-zoomOutTitle="kendo.pdfviewer.zoomOutTitle|The ZoomOut tool title and label."
            zoomOutTitle="Zoom out"
            
            i18n-selectionTitle="kendo.pdfviewer.selectionTitle|The Selection tool title and label."
            selectionTitle="Enable selection"
            
            i18n-panningTitle="kendo.pdfviewer.panningTitle|The Panning tool title and label."
            panningTitle="Enable panning"
            
            i18n-searchTitle="kendo.pdfviewer.searchTitle|The Search tool title and label."
            searchTitle="Search"
            
            i18n-openTitle="kendo.pdfviewer.openTitle|The Open tool title and label."
            openTitle="Open"
            
            i18n-downloadTitle="kendo.pdfviewer.downloadTitle|The Download tool title and label."
            downloadTitle="Download"
            
            i18n-printTitle="kendo.pdfviewer.printTitle|The Print tool title and label."
            printTitle="Print"
            
            i18n-fitToPage="kendo.pdfviewer.fitToPage|The text for the zoom level chooser Fit to page option."
            fitToPage="Fit to page"
            
            i18n-fitToWidth="kendo.pdfviewer.fitToWidth|The text for the zoom level chooser Fit to width option."
            fitToWidth="Fit to width"
            
            i18n-searchInputPlaceholder="kendo.pdfviewer.searchInputPlaceholder|The text for the search input placeholder."
            searchInputPlaceholder="Search"
            
            i18n-searchMatchesOf="kendo.pdfviewer.searchMatchesOf|The text before the total number of matches in the Search tool."
            searchMatchesOf="of"
            
            i18n-searchPreviousMatchTitle="kendo.pdfviewer.searchPreviousMatchTitle|The title of the Search tool previous match button."
            searchPreviousMatchTitle="Previous match"
            
            i18n-searchNextMatchTitle="kendo.pdfviewer.searchNextMatchTitle|The title of the Search tool next match button."
            searchNextMatchTitle="Next match"
            
            i18n-searchCloseTitle="kendo.pdfviewer.searchCloseTitle|The title of the Search tool close button."
            searchCloseTitle="Close"
            
            i18n-searchMatchCaseTitle="kendo.pdfviewer.searchMatchCaseTitle|The title of the Search tool match case button."
            searchMatchCaseTitle="Match case"
            
            i18n-zoomInputPlaceholder="kendo.pdfviewer.zoomInputPlaceholder|The text for the zoom tool input placeholder."
            zoomInputPlaceholder="Choose zoom level">
        </ng-container>
        <div kendoPDFViewerLoader 
            *ngIf="loading"
            [settings]="loaderSettings"></div>
        <div kendoPDFViewerToolbar
            #toolbar
            role="toolbar"
            [attr.aria-controls]="pagesContainerId"
            [tools]="tools"
            [skip]="skip"
            [total]="pdfContext?.pdfPages.length ? pdfContext?.pdfPages.length : 1"
            [pageSize]="1"
            [zoomInDisabled]="zoom >= maxZoom || !pdfContext?.pdfDoc"
            [zoomOutDisabled]="zoom <= minZoom || !pdfContext?.pdfDoc"
            [zoomOptionsData]="zoomOptionsData"
            [zoomLevelChooserValue]="zoomLevel"
            [disabledTools]="!pdfContext?.pdfDoc"
            (pageChange)="onPageChange($event)"
            (fileSelect)="onFileSelect($event)"
            (fileSelectStart)="loading = true;"
            (fileSelectError)="onFileSelectError($event)"
            (download)="onDownload()"
            (panningEnabled)="enabledSelection = false;"
            (selectionEnabled)="enabledSelection = true;"
            (zoomIn)="onZoomIn()"
            (zoomOut)="onZoomOut()"
            (zoomLevelChange)="onZoomLevelChange($event)"
            (print)="onPrint()"
            (search)="onSearch()"></div>
        <div
            class="k-canvas k-pdf-viewer-canvas k-pos-relative k-overflow-auto"
            [class.k-enable-text-select]="enabledSelection"
            [class.k-enable-panning]="!enabledSelection"
            [attr.aria-describedby]="activePageId"
            tabindex="0">
            <div
                kendoPDFViewerSearch
                *ngIf="searchActive"
                [currentMatch]="currentMatch"
                [matches]="currentMatches.length"
                class="k-search-panel k-pos-sticky k-top-center"
                (searchChange)="onSearchChange($event)"
                (prevMatch)="onPreviousMatch()"
                (nextMatch)="onNextMatch()"
                (close)="closeSearch(toolbar)"></div>
            <div 
                #pagesContainer
                [kendoEventsOutsideAngular]="{
                    wheel: stopPropagation
                }"
                class="k-pdf-viewer-pages"
                [attr.id]="pagesContainerId"></div>
        </div>

        <div kendoWatermarkOverlay *ngIf="showLicenseWatermark"></div>
    `, isInline: true, dependencies: [{ kind: "directive", type: LocalizedPDFViewerMessagesDirective, selector: "[kendoPDFViewerLocalizedMessages]" }, { kind: "directive", type: NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: EventsOutsideAngularDirective, selector: "[kendoEventsOutsideAngular]", inputs: ["kendoEventsOutsideAngular", "scope"] }, { kind: "component", type: LoaderComponent, selector: "[kendoPDFViewerLoader]", inputs: ["settings"] }, { kind: "component", type: ToolbarComponent, selector: "[kendoPDFViewerToolbar]", inputs: ["zoomLevel", "calculatedComboBoxValue", "skip", "pageSize", "total", "zoomInDisabled", "zoomOutDisabled", "disabledTools", "zoomLevelChooserValue", "zoomOptionsData", "pagesContainerId", "tools"], outputs: ["fileSelect", "fileSelectStart", "fileSelectError", "download", "selectionEnabled", "panningEnabled", "pageChange", "zoomIn", "zoomOut", "zoomLevelChange", "print", "search"] }, { kind: "component", type: PDFViewerSearchComponent, selector: "[kendoPDFViewerSearch]", inputs: ["matches", "currentMatch"], outputs: ["searchChange", "prevMatch", "nextMatch", "close"] }, { kind: "component", type: WatermarkOverlayComponent, selector: "div[kendoWatermarkOverlay]" }] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerComponent, decorators: [{
            type: Component,
            args: [{
                    exportAs: 'kendo-pdfviewer',
                    selector: 'kendo-pdfviewer',
                    providers: [
                        LocalizationService,
                        {
                            provide: L10N_PREFIX,
                            useValue: 'kendo.pdfviewer'
                        }
                    ],
                    template: `
        <ng-container kendoPDFViewerLocalizedMessages
            i18n-pagerFirstPage="kendo.pdfviewer.pagerFirstPage|The label for the first page button in the Pager"
            pagerFirstPage="Go to the first page"

            i18n-pagerPreviousPage="kendo.pdfviewer.pagerPreviousPage|The label for the previous page button in the Pager"
            pagerPreviousPage="Go to the previous page"

            i18n-pagerNextPage="kendo.pdfviewer.pagerNextPage|The label for the next page button in the Pager"
            pagerNextPage="Go to the next page"

            i18n-pagerLastPage="kendo.pdfviewer.pagerLastPage|The label for the last page button in the Pager"
            pagerLastPage="Go to the last page"

            i18n-pagerPage="kendo.pdfviewer.pagerPage|The text before the current page number in the Pager"
            pagerPage="Page"

            i18n-pagerOf="kendo.pdfviewer.pagerOf|The text before the total pages number in the Pager"
            pagerOf="of"

            i18n-pagerInputTitle="kendo.pdfviewer.pagerInputTitle|The label of the pager input element"
            pagerInputTitle="Page Number"

            i18n-pagerInputLabel="kendo.pdfviewer.pagerInputLabel|The text of the aria-label attribute applied to the input element for entering the page number."
            pagerInputLabel="Type a page number"
            
            i18n-zoomInTitle="kendo.pdfviewer.zoomInTitle|The ZoomIn tool title and label."
            zoomInTitle="Zoom in"
            
            i18n-zoomOutTitle="kendo.pdfviewer.zoomOutTitle|The ZoomOut tool title and label."
            zoomOutTitle="Zoom out"
            
            i18n-selectionTitle="kendo.pdfviewer.selectionTitle|The Selection tool title and label."
            selectionTitle="Enable selection"
            
            i18n-panningTitle="kendo.pdfviewer.panningTitle|The Panning tool title and label."
            panningTitle="Enable panning"
            
            i18n-searchTitle="kendo.pdfviewer.searchTitle|The Search tool title and label."
            searchTitle="Search"
            
            i18n-openTitle="kendo.pdfviewer.openTitle|The Open tool title and label."
            openTitle="Open"
            
            i18n-downloadTitle="kendo.pdfviewer.downloadTitle|The Download tool title and label."
            downloadTitle="Download"
            
            i18n-printTitle="kendo.pdfviewer.printTitle|The Print tool title and label."
            printTitle="Print"
            
            i18n-fitToPage="kendo.pdfviewer.fitToPage|The text for the zoom level chooser Fit to page option."
            fitToPage="Fit to page"
            
            i18n-fitToWidth="kendo.pdfviewer.fitToWidth|The text for the zoom level chooser Fit to width option."
            fitToWidth="Fit to width"
            
            i18n-searchInputPlaceholder="kendo.pdfviewer.searchInputPlaceholder|The text for the search input placeholder."
            searchInputPlaceholder="Search"
            
            i18n-searchMatchesOf="kendo.pdfviewer.searchMatchesOf|The text before the total number of matches in the Search tool."
            searchMatchesOf="of"
            
            i18n-searchPreviousMatchTitle="kendo.pdfviewer.searchPreviousMatchTitle|The title of the Search tool previous match button."
            searchPreviousMatchTitle="Previous match"
            
            i18n-searchNextMatchTitle="kendo.pdfviewer.searchNextMatchTitle|The title of the Search tool next match button."
            searchNextMatchTitle="Next match"
            
            i18n-searchCloseTitle="kendo.pdfviewer.searchCloseTitle|The title of the Search tool close button."
            searchCloseTitle="Close"
            
            i18n-searchMatchCaseTitle="kendo.pdfviewer.searchMatchCaseTitle|The title of the Search tool match case button."
            searchMatchCaseTitle="Match case"
            
            i18n-zoomInputPlaceholder="kendo.pdfviewer.zoomInputPlaceholder|The text for the zoom tool input placeholder."
            zoomInputPlaceholder="Choose zoom level">
        </ng-container>
        <div kendoPDFViewerLoader 
            *ngIf="loading"
            [settings]="loaderSettings"></div>
        <div kendoPDFViewerToolbar
            #toolbar
            role="toolbar"
            [attr.aria-controls]="pagesContainerId"
            [tools]="tools"
            [skip]="skip"
            [total]="pdfContext?.pdfPages.length ? pdfContext?.pdfPages.length : 1"
            [pageSize]="1"
            [zoomInDisabled]="zoom >= maxZoom || !pdfContext?.pdfDoc"
            [zoomOutDisabled]="zoom <= minZoom || !pdfContext?.pdfDoc"
            [zoomOptionsData]="zoomOptionsData"
            [zoomLevelChooserValue]="zoomLevel"
            [disabledTools]="!pdfContext?.pdfDoc"
            (pageChange)="onPageChange($event)"
            (fileSelect)="onFileSelect($event)"
            (fileSelectStart)="loading = true;"
            (fileSelectError)="onFileSelectError($event)"
            (download)="onDownload()"
            (panningEnabled)="enabledSelection = false;"
            (selectionEnabled)="enabledSelection = true;"
            (zoomIn)="onZoomIn()"
            (zoomOut)="onZoomOut()"
            (zoomLevelChange)="onZoomLevelChange($event)"
            (print)="onPrint()"
            (search)="onSearch()"></div>
        <div
            class="k-canvas k-pdf-viewer-canvas k-pos-relative k-overflow-auto"
            [class.k-enable-text-select]="enabledSelection"
            [class.k-enable-panning]="!enabledSelection"
            [attr.aria-describedby]="activePageId"
            tabindex="0">
            <div
                kendoPDFViewerSearch
                *ngIf="searchActive"
                [currentMatch]="currentMatch"
                [matches]="currentMatches.length"
                class="k-search-panel k-pos-sticky k-top-center"
                (searchChange)="onSearchChange($event)"
                (prevMatch)="onPreviousMatch()"
                (nextMatch)="onNextMatch()"
                (close)="closeSearch(toolbar)"></div>
            <div 
                #pagesContainer
                [kendoEventsOutsideAngular]="{
                    wheel: stopPropagation
                }"
                class="k-pdf-viewer-pages"
                [attr.id]="pagesContainerId"></div>
        </div>

        <div kendoWatermarkOverlay *ngIf="showLicenseWatermark"></div>
    `,
                    standalone: true,
                    imports: [LocalizedPDFViewerMessagesDirective, NgIf, EventsOutsideAngularDirective, LoaderComponent, ToolbarComponent, PDFViewerSearchComponent, WatermarkOverlayComponent]
                }]
        }], ctorParameters: function () { return [{ type: i0.NgZone }, { type: i0.Renderer2 }, { type: i1.LocalizationService }, { type: i0.ChangeDetectorRef }, { type: i0.ElementRef }]; }, propDecorators: { hostClass: [{
                type: HostBinding,
                args: ['class.k-pdf-viewer']
            }], direction: [{
                type: HostBinding,
                args: ['attr.dir']
            }], tools: [{
                type: Input
            }], loaderSettings: [{
                type: Input
            }], saveFileName: [{
                type: Input
            }], saveOptions: [{
                type: Input
            }], url: [{
                type: Input
            }], data: [{
                type: Input
            }], arrayBuffer: [{
                type: Input
            }], typedArray: [{
                type: Input
            }], zoom: [{
                type: Input
            }], zoomRate: [{
                type: Input
            }], minZoom: [{
                type: Input
            }], maxZoom: [{
                type: Input
            }], loadOnDemand: [{
                type: Input
            }], loadOnDemandPageSize: [{
                type: Input
            }], load: [{
                type: Output
            }], error: [{
                type: Output
            }], download: [{
                type: Output
            }], pageChange: [{
                type: Output
            }], zoomLevelChange: [{
                type: Output
            }], pagesContainer: [{
                type: ViewChild,
                args: ['pagesContainer']
            }] } });

/**
 * Use the `KENDO_PDFVIEWER` utility array to add all `@progress/kendo-angular-pdf-viewer`-related components and directives to a standalone Angular component.
 *
 * @example
 * ```typescript
 * import { Component } from '@angular/core';
 * import { KENDO_PDFVIEWER } from "@progress/kendo-angular-pdf-viewer";
 *
 * @Component({
 *   standalone: true,
 *   imports: [KENDO_PDFVIEWER],
 *   selector: 'my-app',
 *   template: `<kendo-pdf-viewer [url]="pdfUrl"></kendo-pdf-viewer>`
 * })
 * export class AppComponent {}
 * ```
 */
const KENDO_PDFVIEWER = [
    PDFViewerComponent,
    PDFViewerCustomMessagesComponent
];

// IMPORTANT: NgModule export kept for backwards compatibility
/**
 * Represents the [`NgModule`](link:site.data.urls.angular['ngmoduleapi']) definition for the PDFViewer component.
 *
 * @example
 * ```typescript
 * import { NgModule } from '@angular/core';
 * import { BrowserModule } from '@angular/platform-browser';
 * import { PDFViewerModule } from '@progress/kendo-angular-pdf-viewer';
 * import { AppComponent } from './app.component';
 *
 * @NgModule({
 *   declarations: [AppComponent],
 *   imports: [BrowserModule, PDFViewerModule],
 *   bootstrap: [AppComponent]
 * })
 * export class AppModule {}
 * ```
 */
class PDFViewerModule {
    static ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
    static ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerModule, imports: [PDFViewerComponent, PDFViewerCustomMessagesComponent], exports: [PDFViewerComponent, PDFViewerCustomMessagesComponent] });
    static ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerModule, providers: [
            IconsService,
            PopupService,
            ResizeBatchService
        ], imports: [PDFViewerComponent] });
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "16.2.12", ngImport: i0, type: PDFViewerModule, decorators: [{
            type: NgModule,
            args: [{
                    exports: [...KENDO_PDFVIEWER],
                    imports: [...KENDO_PDFVIEWER],
                    providers: [
                        IconsService,
                        PopupService,
                        ResizeBatchService
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { KENDO_PDFVIEWER, LoaderComponent, LocalizedPDFViewerMessagesDirective, PDFViewerComponent, PDFViewerCustomMessagesComponent, PDFViewerDownloadEvent, PDFViewerModule, PDFViewerSearchComponent, ToolbarComboBoxDirective, ToolbarComponent, ToolbarFocusableDirective, ToolbarInputWrapperComponent };

